@@ -28,18 +28,21 @@
 #include <goffice/graph/goffice-graph.h>
 #include <goffice/graph/gog-graph.h>
 #include <goffice/graph/gog-chart.h>
+#include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-plot-impl.h>
 #include <goffice/graph/gog-series-impl.h>
 #include <goffice/graph/gog-object.h>
 #include <goffice/graph/gog-styled-object.h>
 #include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-plot-engine.h>
+#include <goffice/graph/go-data-simple.h>
 #include <goffice/utils/go-color.h>
 #include <goffice/utils/go-pattern.h>
 #include <goffice/utils/go-marker.h>
 
 #include <gsf/gsf-utils.h>
 #include <math.h>
+#include <string.h>
 #include <stdio.h>
 
 /* #define NO_DEBUG_EXCEL */
@@ -55,6 +58,7 @@ typedef struct _XLChartSeries {
 		GOData *data;
 	} data [GOG_MS_DIM_TYPES];
 	int chart_group;
+	GogStyle *style;
 } XLChartSeries;
 
 typedef struct {
@@ -68,14 +72,18 @@ typedef struct {
 	GogGraph	*graph;
 	GogChart	*chart;
 	GogPlot		*plot;
+	GogStyle	*default_plot_style;
 	GogObject	*axis;
-
 	GogStyle	*style;
+
 	int		 style_element;
 
-	int plot_counter;
-	XLChartSeries *currentSeries;
-	GPtrArray	 *series;
+	gboolean	 frame_for_grid;
+	gboolean	 has_a_grid;
+	int		 plot_counter;
+	XLChartSeries	*currentSeries;
+	GPtrArray	*series;
+	char		*text;
 } XLChartReadState;
 
 typedef struct {
@@ -104,6 +112,7 @@ excel_chart_series_new (void)
 	series = g_new (XLChartSeries, 1);
 
 	series->chart_group = -1;
+	series->style = NULL;
 	for (i = GOG_MS_DIM_TYPES; i-- > 0 ; ) {
 		series->data [i].data = NULL;
 		series->data [i].num_elements = 0;
@@ -120,9 +129,19 @@ excel_chart_series_delete (XLChartSeries *series)
 	for (i = GOG_MS_DIM_TYPES; i-- > 0 ; )
 		if (series->data [i].data != NULL)
 			g_object_unref (series->data[i].data);
+	if (series->style != NULL)
+		g_object_unref (series->style);
 	g_free (series);
 }
 
+static void
+BC_R(get_style) (XLChartReadState *s)
+{
+	if (s->style == NULL) {
+		s->style = gog_style_new ();
+		s->style->needs_obj_defaults = FALSE;
+	}
+}
 
 static int
 BC_R(top_state) (XLChartReadState *s)
@@ -134,15 +153,13 @@ BC_R(top_state) (XLChartReadState *s)
 static GOColor
 BC_R(color) (guint8 const *data, char const *type)
 {
-	guint32 const rgb = GSF_LE_GET_GUINT32 (data);
+	guint32 const bgr = GSF_LE_GET_GUINT32 (data);
+	guint16 const r = (bgr >>  0) & 0xff;
+	guint16 const g = (bgr >>  8) & 0xff;
+	guint16 const b = (bgr >> 16) & 0xff;
 
-	d (1, {
-		guint16 const r = (rgb >>  0) & 0xff;
-		guint16 const g = (rgb >>  8) & 0xff;
-		guint16 const b = (rgb >> 16) & 0xff;
-		fprintf(stderr, "%s %02x:%02x:%02x;\n", type, r, g, b);
-	});
-	return RGB_TO_RGBA (rgb, 0xff);
+	d (1, fprintf(stderr, "%s %02x:%02x:%02x;\n", type, r, g, b););
+	return RGBA_TO_UINT (r, g, b, 0xff);
 }
 
 /****************************************************************************/
@@ -227,7 +244,7 @@ BC_R(ai)(XLChartHandler const *handle,
 
 	/* Rest are 0 */
 	if (flags&0x01) {
-		StyleFormat *fmt = ms_container_get_fmt (&s->container,
+		GnmFormat *fmt = ms_container_get_fmt (&s->container,
 			GSF_LE_GET_GUINT16 (q->data + 4));
 		d (2, fputs ("Has Custom number format", stderr););
 		if (fmt != NULL) {
@@ -351,21 +368,36 @@ BC_R(areaformat)(XLChartHandler const *handle,
 	d (0, {
 		fprintf (stderr, "pattern = %d;\n", pattern);
 		if (auto_format)
-			fputs ("Use auto format;", stderr);
+			fputs ("Use auto format;\n", stderr);
 		if (invert_if_negative)
-			fputs ("Swap fore and back colours when displaying negatives;", stderr);
+			fputs ("Swap fore and back colours when displaying negatives;\n", stderr);
 	});
 
-	/* These apply to frames also */
-	if (s->style == NULL)
-		return FALSE;
-
-	s->style->fill.type = GOG_FILL_STYLE_PATTERN;
-	s->style->fill.is_auto = auto_format;
-	s->style->fill.invert_if_negative = invert_if_negative;
-	s->style->fill.u.pattern.pat.pattern = pattern;
-	s->style->fill.u.pattern.pat.fore = BC_R(color) (q->data+0, "AreaFore");
-	s->style->fill.u.pattern.pat.back = BC_R(color) (q->data+4, "AreaBack");
+#if 0 
+	/* 18 */ "5%"
+#endif
+	BC_R(get_style) (s);
+	if (pattern > 0) {
+		s->style->fill.type = GOG_FILL_STYLE_PATTERN;
+		s->style->fill.is_auto = auto_format;
+		s->style->fill.invert_if_negative = invert_if_negative;
+		s->style->fill.u.pattern.pat.pattern = pattern - 1;
+		s->style->fill.u.pattern.pat.fore = BC_R(color) (q->data+0, "AreaFore");
+		s->style->fill.u.pattern.pat.back = BC_R(color) (q->data+4, "AreaBack");
+		if (s->style->fill.u.pattern.pat.pattern == 0) {
+			GOColor tmp = s->style->fill.u.pattern.pat.fore;
+			s->style->fill.u.pattern.pat.fore = s->style->fill.u.pattern.pat.back;
+			s->style->fill.u.pattern.pat.back = tmp;
+		}
+	} else if (auto_format) {
+		s->style->fill.type = GOG_FILL_STYLE_PATTERN;
+		s->style->fill.is_auto = TRUE;
+		s->style->fill.invert_if_negative = invert_if_negative;
+		s->style->fill.u.pattern.pat.pattern = 0;
+		s->style->fill.u.pattern.pat.fore =
+		s->style->fill.u.pattern.pat.back = 0;
+	} else
+		s->style->fill.type = GOG_FILL_STYLE_NONE;
 
 	return FALSE;
 }
@@ -532,7 +564,7 @@ static gboolean
 BC_R(begin)(XLChartHandler const *handle,
 	    XLChartReadState *s, BiffQuery *q)
 {
-	d(0, fputs ("{", stderr););
+	d(0, fputs ("{\n", stderr););
 	s->stack = g_array_append_val (s->stack, s->prev_opcode);
 	return FALSE;
 }
@@ -663,7 +695,7 @@ BC_R(clrtclient)(XLChartHandler const *handle,
 		 XLChartReadState *s, BiffQuery *q)
 {
 	fputs ("Undocumented BIFF : clrtclient", stderr);
-	dump_biff (q);
+	ms_biff_query_dump (q);
 	return FALSE;
 }
 /****************************************************************************/
@@ -695,7 +727,6 @@ BC_R(dataformat)(XLChartHandler const *handle,
 	guint16 const excel4_auto_color = GSF_LE_GET_GUINT16 (q->data+6) & 0x01;
 #endif
 
-	g_return_val_if_fail (s->style == NULL, TRUE);
 	g_return_val_if_fail (series_index < s->series->len, TRUE);
 
 	series = g_ptr_array_index (s->series, series_index);
@@ -709,7 +740,6 @@ BC_R(dataformat)(XLChartHandler const *handle,
 		s->style_element = pt_num;
 		d (0, fprintf (stderr, "Point-%hd", pt_num););
 	}
-	s->style = gog_style_new ();
 
 	d (0, fprintf (stderr, ", series=%hd\n", series_index););
 
@@ -790,17 +820,21 @@ static gboolean
 BC_R(frame)(XLChartHandler const *handle,
 	    XLChartReadState *s, BiffQuery *q)
 {
+#if 0
 	guint16 const type = GSF_LE_GET_GUINT16 (q->data);
 	guint16 const flags = GSF_LE_GET_GUINT16 (q->data+2);
 	gboolean border_shadow, auto_size, auto_pos;
 
-#if 0
 	g_return_val_if_fail (type == 1 || type ==4, TRUE);
-#endif
 	/* FIXME FIXME FIXME : figure out what other values are */
 	border_shadow = (type == 4) ? TRUE : FALSE;
 	auto_size = (flags&0x01) ? TRUE : FALSE;
 	auto_pos = (flags&0x02) ? TRUE : FALSE;
+#endif
+
+	s->frame_for_grid = (s->prev_opcode == BIFF_CHART_plotarea);
+	s->has_a_grid |= s->frame_for_grid;
+	d (0, fputs (s->frame_for_grid ? "For grid;\n" : "Not for grid;\n", stderr););
 
 	return FALSE;
 }
@@ -808,29 +842,39 @@ BC_R(frame)(XLChartHandler const *handle,
 /****************************************************************************/
 
 static gboolean
-BC_R(gelframe)(XLChartHandler const *handle,
-	       XLChartReadState *s, BiffQuery *q)
+BC_R(gelframe) (XLChartHandler const *handle,
+		XLChartReadState *s, BiffQuery *q)
 {
-	gint tmp = ms_excel_escher_debug;
-	ms_excel_escher_debug = 2;
-	ms_escher_parse (q, &s->container);
-	ms_excel_escher_debug = tmp;
+	MSObjAttrBag *attrs = ms_escher_parse (q, &s->container);
+
+#if 0
+	MSObjAttr *crop_bottom_attr = ms_obj_attr_bag_lookup
+		(obj->attrs, MS_OBJ_ATTR_BLIP_CROP_BOTTOM);
+	MS_OBJ_ATTR_FILL_TYPE;
+#endif
+	ms_obj_attr_bag_destroy (attrs);
+
 	return FALSE;
 }
+
 /****************************************************************************/
 
 static gboolean
 BC_R(ifmt)(XLChartHandler const *handle,
 	   XLChartReadState *s, BiffQuery *q)
 {
-	StyleFormat *fmt = ms_container_get_fmt (&s->container,
+	GnmFormat *fmt = ms_container_get_fmt (&s->container,
 		GSF_LE_GET_GUINT16 (q->data));
 
 	if (fmt != NULL) {
-		char * desc = style_format_as_XL (fmt, FALSE);
+		char *desc = style_format_as_XL (fmt, FALSE);
+
+		if (s->axis != NULL)
+			g_object_set (G_OBJECT (s->axis),
+				"assigned-format-string-XL", desc,
+				NULL);
 		d (0, fprintf (stderr, "Format = '%s';\n", desc););
 		g_free (desc);
-
 		style_format_unref (fmt);
 	}
 
@@ -860,12 +904,12 @@ BC_R(legend)(XLChartHandler const *handle,
 	case 0: pos = GOG_POSITION_S | GOG_POSITION_ALIGN_CENTER; break;
 	case 1: pos = GOG_POSITION_N | GOG_POSITION_E; break;
 	case 2: pos = GOG_POSITION_N | GOG_POSITION_ALIGN_CENTER; break;
-	case 3: pos = GOG_POSITION_E | GOG_POSITION_ALIGN_CENTER; break;
-	case 4: pos = GOG_POSITION_W | GOG_POSITION_ALIGN_CENTER; break;
-	case 7: break; /* treat floating legends as being on east */
 	default :
 		g_warning ("Unknown legend position (%d), assuming east.",
 			   XL_pos);
+	case 3: pos = GOG_POSITION_E | GOG_POSITION_ALIGN_CENTER; break;
+	case 4: pos = GOG_POSITION_W | GOG_POSITION_ALIGN_CENTER; break;
+	case 7: break; /* treat floating legends as being on east */
 	};
 
 	legend = gog_object_add_by_name (GOG_OBJECT (s->chart), "Legend", NULL);
@@ -937,34 +981,31 @@ BC_R(lineformat)(XLChartHandler const *handle,
 		 XLChartReadState *s, BiffQuery *q)
 {
 	guint16 const flags = GSF_LE_GET_GUINT16 (q->data+8);
-	GogStyle *style = s->style;
-
-	if (style == NULL) {
-		if (s->axis != NULL)
-			style = gog_styled_object_get_style (GOG_STYLED_OBJECT (s->axis));
-		if (style == NULL)
-			return FALSE;
-	}
 
+	BC_R(get_style) (s);
 	switch (GSF_LE_GET_GUINT16 (q->data+6)) {
 	default :
-	case -1 : style->line.width = 0; /* hairline */
+	case -1 : s->style->line.width = 0; /* hairline */
 		break;
-	case  0 : style->line.width = 1; /* 'normal' */
+	case  0 : s->style->line.width = 1; /* 'normal' */
 		break;
-	case  1 : style->line.width = 3; /* 'medium' */
+	case  1 : s->style->line.width = 2; /* 'medium' */
 		break;
-	case  2 : style->line.width = 5; /* 'wide' */
+	case  2 : s->style->line.width = 3; /* 'wide' */
 		break;
 	}
-	style->line.color      = BC_R(color) (q->data, "LineColor");
-	style->line.auto_color = (flags & 0x01) ? TRUE : FALSE;
-	style->line.pattern    = GSF_LE_GET_GUINT16 (q->data+4);
+	s->style->line.color      = BC_R(color) (q->data, "LineColor");
+	s->style->line.auto_color = (flags & 0x01) ? TRUE : FALSE;
+	s->style->line.pattern    = GSF_LE_GET_GUINT16 (q->data+4);
 
+	d (0, fprintf (stderr, "flags == %hd.\n", flags););
 	d (0, fprintf (stderr, "Lines are %f pts wide.\n", s->style->line.width););
 	d (0, fprintf (stderr, "Lines have a %s pattern.\n",
 		       ms_line_pattern [s->style->line.pattern ]););
 
+	if (s->style->line.pattern == 5) /* invisible */
+		s->style->line.width = -1;
+
 	return FALSE;
 }
 
@@ -993,11 +1034,9 @@ BC_R(markerformat)(XLChartHandler const *handle,
 	GOMarker *marker;
 	guint16 shape = GSF_LE_GET_GUINT16 (q->data+8);
 	guint16 const flags = GSF_LE_GET_GUINT16 (q->data+10);
-	/* gboolean const auto_color = (flags & 0x01) ? TRUE : FALSE; */
-
-	if (s->style == NULL)
-		return FALSE;
+	gboolean const auto_color = (flags & 0x01) ? TRUE : FALSE;
 
+	BC_R(get_style) (s);
 	marker = go_marker_new ();
 
 	d (0, fprintf (stderr, "Marker = %s\n", ms_chart_marker [shape]););
@@ -1010,10 +1049,14 @@ BC_R(markerformat)(XLChartHandler const *handle,
 	go_marker_set_fill_color (marker, 
 		(flags & 0x10) ? 0 : BC_R(color) (q->data + 4, "MarkerBack"));
 
+	s->style->marker.auto_shape = shape > 0;
+	s->style->marker.auto_outline_color =
+		s->style->marker.auto_fill_color = auto_color;
+
 	if (s->container.ver >= MS_BIFF_V8) {
 		guint32 const marker_size = GSF_LE_GET_GUINT32 (q->data+16);
-		go_marker_set_size (marker, marker_size);
-		d (1, fprintf (stderr, "Marker is %u\n", marker_size););
+		go_marker_set_size (marker, marker_size / 20.);
+		d (1, fprintf (stderr, "Marker size : is %f pts\n", marker_size / 20.););
 	}
 
 	gog_style_set_marker (s->style, marker);
@@ -1027,13 +1070,47 @@ static gboolean
 BC_R(objectlink)(XLChartHandler const *handle,
 		 XLChartReadState *s, BiffQuery *q)
 {
-	d (2, {
 	guint16 const purpose = GSF_LE_GET_GUINT16 (q->data);
+	GogObject *label = NULL;
+	
+	if (s->text == NULL)
+		return FALSE;
+
+	if (purpose == 1) {
+		g_return_val_if_fail (s->chart != NULL, FALSE);
+		label = gog_object_add_by_name (GOG_OBJECT (s->chart), "Title", NULL);
+	} else if (purpose == 2 || purpose == 3 || purpose == 7) {
+		GSList *axes;
+		GogAxisType t;
+
+		g_return_val_if_fail (s->chart != NULL, FALSE);
+
+		switch (purpose) {
+		case 2: t = GOG_AXIS_Y; break;
+		case 3: t = GOG_AXIS_X; break;
+		case 7: t = GOG_AXIS_Z; break;
+		default :
+			g_warning ("Unknown axis type %d", purpose);
+			return FALSE;
+		}
+		axes = gog_chart_get_axis (s->chart, t);
+
+		g_return_val_if_fail (axes != NULL, FALSE);
+
+		label = gog_object_add_by_name (GOG_OBJECT (axes->data), "Label", NULL);
+	}
+
+	if (label != NULL) {
+		gog_dataset_set_dim (GOG_DATASET (label), 0,
+			go_data_scalar_str_new (s->text, TRUE), NULL);
+		s->text = NULL;
+	}
+
+	d (2, {
 	guint16 const series_num = GSF_LE_GET_GUINT16 (q->data+2);
 	guint16 const pt_num = GSF_LE_GET_GUINT16 (q->data+2);
 
-	switch (purpose)
-	{
+	switch (purpose) {
 	case 1 : fprintf (stderr, "TEXT is chart title\n"); break;
 	case 2 : fprintf (stderr, "TEXT is Y axis title\n"); break;
 	case 3 : fprintf (stderr, "TEXT is X axis title\n"); break;
@@ -1159,6 +1236,9 @@ static gboolean
 BC_R(radar)(XLChartHandler const *handle,
 	    XLChartReadState *s, BiffQuery *q)
 {
+	g_return_val_if_fail (s->plot == NULL, TRUE);
+	s->plot = gog_plot_new_by_name ("GogRadialPlot UNIMPLEMENTED");
+
 	return FALSE;
 }
 
@@ -1168,6 +1248,9 @@ static gboolean
 BC_R(radararea)(XLChartHandler const *handle,
 		XLChartReadState *s, BiffQuery *q)
 {
+	g_return_val_if_fail (s->plot == NULL, TRUE);
+	s->plot = gog_plot_new_by_name ("GogFilledRadialPlot UNIMPLEMENTED");
+
 	return FALSE;
 }
 
@@ -1323,12 +1406,15 @@ BC_R(seriestext)(XLChartHandler const *handle,
 		s->currentSeries->data [GOG_MS_DIM_LABELS].data =
 			gnm_go_data_scalar_new_expr (
 				ms_container_sheet (s->container.parent),
-				gnm_expr_new_constant (value_new_string (str)));
-	}
-
-	/* TODO : handle axis and chart titles */
-
-	g_free (str);
+				gnm_expr_new_constant (value_new_string_nocopy (str)));
+	} else if (BC_R(top_state) (s) == BIFF_CHART_text) {
+		if (s->text != NULL) {
+			g_warning ("multiple seriestext associated with 1 text record ?");
+			g_free (str);
+		} else
+			s->text = str;
+	} else
+		g_free (str);
 
 	return FALSE;
 }
@@ -1541,39 +1627,46 @@ BC_R(units)(XLChartHandler const *handle,
 /****************************************************************************/
 
 
-static gboolean
-conditional_get_double (gboolean flag, guint8 const *data,
-			gchar const *name)
+static void
+conditional_set_double (gboolean flag, guint8 const *data,
+			gchar const *name, unsigned dim, GogObject *axis)
 {
-	if (!flag) {
+	GOData *dat;
+	if (flag) {
+		dat = NULL;
+		d (1, fprintf (stderr, "%s = Auto\n", name););
+	} else {
 		double const val = gsf_le_get_double (data);
+		gog_dataset_set_dim (GOG_DATASET (axis), dim,
+			go_data_scalar_val_new (val), NULL);
 		d (1, fprintf (stderr, "%s = %f\n", name, val););
-		return TRUE;
 	}
-	d (1, fprintf (stderr, "%s = Auto\n", name););
-	return FALSE;
 }
 
 static gboolean
 BC_R(valuerange)(XLChartHandler const *handle,
 		 XLChartReadState *s, BiffQuery *q)
 {
-	guint16 const flags = gsf_le_get_double (q->data+40);
+	guint16 const flags = GSF_LE_GET_GUINT16 (q->data+40);
 
-	conditional_get_double (flags&0x01, q->data+ 0, "Min Value");
-	conditional_get_double (flags&0x02, q->data+ 8, "Max Value");
-	conditional_get_double (flags&0x04, q->data+16, "Major Increment");
-	conditional_get_double (flags&0x08, q->data+24, "Minor Increment");
-	conditional_get_double (flags&0x10, q->data+32, "Cross over point");
+	conditional_set_double (flags&0x01, q->data+ 0, "Min Value", AXIS_ELEM_MIN, s->axis);
+	conditional_set_double (flags&0x02, q->data+ 8, "Max Value", AXIS_ELEM_MAX, s->axis);
+	conditional_set_double (flags&0x04, q->data+16, "Major Increment", AXIS_ELEM_MAJOR_TICK, s->axis);
+	conditional_set_double (flags&0x08, q->data+24, "Minor Increment", AXIS_ELEM_MINOR_TICK, s->axis);
+	conditional_set_double (flags&0x10, q->data+32, "Cross over point", AXIS_ELEM_CROSS_POINT, s->axis);
 
-	d (1, {
-	if (flags&0x20)
-		fputs ("Log scaled", stderr);
-	if (flags&0x40)
-		fputs ("Values in reverse order", stderr);
-	if (flags&0x80)
-		fputs ("Cross over at max value", stderr);
-	});
+	if (flags & 0x20) {
+		g_object_set (s->axis, "log-scale", TRUE, NULL);
+		d (1, fputs ("Log scaled", stderr););
+	}
+	if (flags & 0x40) {
+		g_object_set (s->axis, "invert-axis", TRUE, NULL);
+		d (1, fputs ("Values in reverse order", stderr););
+	}
+	if (flags & 0x80) {
+		g_object_set (s->axis, "pos_str", "high", NULL);
+		d (1, fputs ("Cross over at max value", stderr););
+	}
 
 	return FALSE;
 }
@@ -1596,6 +1689,7 @@ XL_gog_series_set_dim (GogSeries *series, GogMSDimType ms_type, GOData *val)
 			return;
 		}
 	g_warning ("Unexpected val for dim %d", ms_type);
+	g_object_unref (val);
 }
 
 static gboolean
@@ -1604,7 +1698,7 @@ BC_R(end)(XLChartHandler const *handle,
 {
 	int popped_state;
 
-	d (0, fputs ("}", stderr););
+	d (0, fputs ("}\n", stderr););
 
 	g_return_val_if_fail (s->stack != NULL, TRUE);
 	g_return_val_if_fail (s->stack->len > 0, TRUE);
@@ -1614,9 +1708,37 @@ BC_R(end)(XLChartHandler const *handle,
 
 	switch (popped_state) {
 	case BIFF_CHART_axis :
+		if (s->style != NULL) {
+			g_object_set (G_OBJECT (s->axis),
+				"style", s->style,
+				NULL);
+			g_object_unref (s->style);
+			s->style = NULL;
+		}
 		s->axis = NULL;
 		break;
 
+	case BIFF_CHART_frame :
+		if (s->style != NULL) {
+			GogObject *obj;
+			if (s->chart != NULL) {
+				if (s->frame_for_grid) {
+					GogGrid *tmp = gog_chart_get_grid (s->chart);
+					obj = (tmp == NULL)
+						? gog_object_add_by_name (GOG_OBJECT (s->chart), "Grid", NULL)
+						: GOG_OBJECT (tmp);
+				} else
+					obj = GOG_OBJECT (s->chart);
+				if (obj != NULL)
+					g_object_set (G_OBJECT (obj),
+						"style", s->style,
+						NULL);
+			}
+			g_object_unref (s->style);
+			s->style = NULL;
+		}
+		break;
+
 	case BIFF_CHART_series :
 		g_return_val_if_fail (s->currentSeries != NULL, TRUE);
 		s->currentSeries = NULL;
@@ -1626,9 +1748,31 @@ BC_R(end)(XLChartHandler const *handle,
 		unsigned i, j;
 		XLChartSeries *eseries;
 		GogSeries     *series;
+		GogStyle      *style;
 
 		g_return_val_if_fail (s->plot != NULL, TRUE);
 
+		if (s->default_plot_style != NULL) {
+			char const  *type = G_OBJECT_TYPE_NAME (s->plot);
+			GogStyle const *style = s->default_plot_style;
+			
+			if (type != NULL && style->marker.mark != NULL &&
+			    (!strcmp (type, "GogXYPlot") ||
+			     !strcmp (type, "GogLinePlot") ||
+			     !strcmp (type, "GogRadialPlot")))
+				g_object_set (G_OBJECT (s->plot),
+					"default-style-has-markers",
+					style->marker.mark->shape != GO_MARKER_NONE,
+					NULL);
+			if (type != NULL && 0 == strcmp (type, "GogXYPlot"))
+				g_object_set (G_OBJECT (s->plot),
+					"default-style-has-lines", style->line.width >= 0,
+					NULL);
+
+			g_object_unref (s->default_plot_style);
+			s->default_plot_style = NULL;
+		}
+
 		for (i = 0 ; i < s->series->len; i++ ) {
 			eseries = g_ptr_array_index (s->series, i);
 			if (eseries->chart_group != s->plot_counter)
@@ -1640,6 +1784,11 @@ BC_R(end)(XLChartHandler const *handle,
 						eseries->data [j].data);
 					eseries->data [j].data = NULL;
 				}
+			style = eseries->style;
+			if (style != NULL)
+				g_object_set (G_OBJECT (series),
+					"style", style,
+					NULL);
 		}
 
 		gog_object_add_by_name (GOG_OBJECT (s->chart),
@@ -1649,11 +1798,26 @@ BC_R(end)(XLChartHandler const *handle,
 	}
 
 	case BIFF_CHART_dataformat :
-		g_return_val_if_fail (s->style != NULL, TRUE);
-		g_object_unref (s->style);
+		if (s->style == NULL)
+			break;
+		if (s->currentSeries != NULL && s->style_element < 0) {
+			g_return_val_if_fail (s->currentSeries->style == NULL, TRUE);
+			s->currentSeries->style = s->style;
+		} else if (s->plot != NULL) {
+			g_return_val_if_fail (s->default_plot_style == NULL, TRUE);
+			s->default_plot_style = s->style;
+		} else
+			g_object_unref (s->style);
 		s->style = NULL;
 		break;
 
+	case BIFF_CHART_text :
+		if (s->text != NULL) {
+			g_free (s->text);
+			s->text = NULL;
+		}
+		break;
+
 	default :
 		break;
 	}
@@ -1808,7 +1972,7 @@ chart_get_sheet (MSContainer const *container)
 	return ms_container_sheet (container->parent);
 }
 
-static StyleFormat *
+static GnmFormat *
 chart_get_fmt (MSContainer const *container, guint16 indx)
 {
 	return ms_container_get_fmt (container->parent, indx);
@@ -1844,6 +2008,8 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 	state.currentSeries = NULL;
 	state.series	    = g_ptr_array_new ();
 	state.plot_counter  = -1;
+	state.has_a_grid    = FALSE;
+	state.text	    = NULL;
 
 	if (NULL != (state.sog = sog)) {
 		state.graph = sheet_object_graph_get_gog (sog);
@@ -1852,6 +2018,7 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 		state.graph = NULL;
 		state.chart = NULL;
 	}
+	state.default_plot_style = NULL;
 	state.plot  = NULL;
 	state.axis  = NULL;
 	state.style = NULL;
@@ -1871,7 +2038,7 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 			    !chart_biff_handler [lsb] ||
 			    chart_biff_handler  [lsb]->opcode != q->opcode) {
 				d (0, {	fprintf (stderr, "Unknown BIFF_CHART record\n");
-					dump_biff (q);});
+					ms_biff_query_dump (q);});
 			} else {
 				XLChartHandler const *const h =
 					chart_biff_handler [lsb];
@@ -1924,7 +2091,7 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 			}
 
 			case BIFF_MS_O_DRAWING:
-				ms_escher_parse (q, &state.container);
+				ms_obj_attr_bag_destroy (ms_escher_parse (q, &state.container));
 				break;
 
 			case BIFF_EXTERNCOUNT: /* ignore */ break;
@@ -1960,12 +2127,22 @@ ms_excel_read_chart (BiffQuery *q, MSContainer *container, MsBiffVersion ver,
 		state.prev_opcode = q->opcode;
 	}
 
+	/* If there was no grid in the stream remove the automatic grid */
+	if (state.chart != NULL && !state.has_a_grid) {
+		GogGrid *grid = gog_chart_get_grid (state.chart);
+		if (grid != NULL) {
+			gog_object_clear_parent (GOG_OBJECT (grid));
+			g_object_unref (grid);
+		}
+	}
+
 	/* Cleanup */
 	for (i = state.series->len; i-- > 0 ; ) {
 		XLChartSeries *series = g_ptr_array_index (state.series, i);
 		if (series != NULL)
 			excel_chart_series_delete (series);
 	}
+	g_array_free (state.stack, TRUE);
 	g_ptr_array_free (state.series, TRUE);
 	ms_container_finalize (&state.container);
 
