@@ -90,7 +90,7 @@ gnm_py_interpreter_new (GnmPlugin *plugin)
 	GnmPyInterpreter *interpreter;
 	PyThreadState *py_thread_state;
 
-	g_return_val_if_fail (plugin == NULL || GNM_IS_PLUGIN (plugin), NULL);
+	g_return_val_if_fail (plugin == NULL || IS_GNM_PLUGIN (plugin), NULL);
 
 	if (plugin != NULL) {
 		py_thread_state = Py_NewInterpreter ();
@@ -113,7 +113,7 @@ void
 gnm_py_interpreter_destroy (GnmPyInterpreter *interpreter,
                             GnmPyInterpreter *new_interpreter)
 {
-	g_return_if_fail (GNM_IS_PY_INTERPRETER (interpreter));
+	g_return_if_fail (IS_GNM_PY_INTERPRETER (interpreter));
 
 	gnm_py_interpreter_switch_to (interpreter);
 	Py_EndInterpreter (interpreter->py_thread_state);
@@ -125,7 +125,7 @@ gnm_py_interpreter_destroy (GnmPyInterpreter *interpreter,
 void
 gnm_py_interpreter_switch_to (GnmPyInterpreter *interpreter)
 {
-	g_return_if_fail (GNM_IS_PY_INTERPRETER (interpreter));
+	g_return_if_fail (IS_GNM_PY_INTERPRETER (interpreter));
 
 	if (PyThreadState_Get ()->interp != interpreter->py_thread_state->interp) {
 		(void) PyThreadState_Swap (interpreter->py_thread_state);
@@ -165,7 +165,7 @@ gnm_py_interpreter_run_string (GnmPyInterpreter *interpreter, const char *cmd,
 	         *saved_stderr_obj = NULL, *stderr_obj = NULL;
 	PyObject *py_str;
 
-	g_return_if_fail (GNM_IS_PY_INTERPRETER (interpreter));
+	g_return_if_fail (IS_GNM_PY_INTERPRETER (interpreter));
 
 	gnm_py_interpreter_switch_to (interpreter);
 
@@ -250,7 +250,7 @@ gnm_py_interpreter_run_string (GnmPyInterpreter *interpreter, const char *cmd,
 const char *
 gnm_py_interpreter_get_name (GnmPyInterpreter *interpreter)
 {
-	g_return_val_if_fail (GNM_IS_PY_INTERPRETER (interpreter), NULL);
+	g_return_val_if_fail (IS_GNM_PY_INTERPRETER (interpreter), NULL);
 
 	if (interpreter->plugin != NULL) {
 		return gnm_plugin_get_name (interpreter->plugin);
@@ -262,7 +262,7 @@ gnm_py_interpreter_get_name (GnmPyInterpreter *interpreter)
 GnmPlugin *
 gnm_py_interpreter_get_plugin (GnmPyInterpreter *interpreter)
 {
-	g_return_val_if_fail (GNM_IS_PY_INTERPRETER (interpreter), NULL);
+	g_return_val_if_fail (IS_GNM_PY_INTERPRETER (interpreter), NULL);
 
 	return interpreter->plugin;
 }
