@@ -73,14 +73,15 @@ qpro_check_signature (GsfInput *input)
 gboolean
 qpro_file_probe (GnmFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
 {
-	GsfInfile *ole;
+	GsfInfileMSOle *ole;
 	GsfInput *stream;
 	gboolean res = FALSE;
 
 	/* check for >= QPro 6.0 which is OLE based */
 	ole = gsf_infile_msole_new (input, NULL);
 	if (ole != NULL) {
-		stream = gsf_infile_child_by_name (ole, "PerfectOffice_MAIN");
+		stream = gsf_infile_child_by_name (GSF_INFILE (ole),
+						   "PerfectOffice_MAIN");
 		if (stream != NULL) {
 			res = qpro_check_signature (stream);
 			g_object_unref (G_OBJECT (stream));
@@ -101,7 +102,7 @@ typedef struct {
 	GIConv          converter;
 } QProReadState;
 
-static Value *
+static GnmValue *
 qpro_new_string (QProReadState *state, gchar const *data)
 {
 	return value_new_string_nocopy (
@@ -354,7 +355,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 	int length = GSF_LE_GET_GUINT16 (data + 10);
 #endif
 	guint16 ref_offset = GSF_LE_GET_GUINT16 (data + 12);
-	Value   *val;
+	GnmValue   *val;
 	GSList  *stack = NULL;
 	GnmExpr const *expr;
 	guint8 const *refs, *fmla;
@@ -389,7 +390,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 			break;
 
 		case QPRO_OP_CELLREF: {
-			CellRef ref;
+			GnmCellRef ref;
 			guint16 tmp = GSF_LE_GET_GUINT16 (refs + 4);
 			ref.sheet = NULL;
 			ref.col = *((gint8 *)(refs + 2));
@@ -405,7 +406,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 		}
 
 		case QPRO_OP_RANGEREF: {
-			CellRef a, b;
+			GnmCellRef a, b;
 			guint16 tmp;
 
 			tmp = GSF_LE_GET_GUINT16 (refs + 4);
@@ -529,7 +530,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 					g_warning ("QPRO function %s is not supported.",
 						   name);
 					for (tmp = stack; tmp; tmp = tmp->next) {
-						ParsePos pp;
+						GnmParsePos pp;
 						char *p;
 
 						pp.wb = state->wb;
@@ -570,7 +571,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 		GSList *tmp;
 
 		for (tmp = stack; tmp; tmp = tmp->next) {
-			ParsePos pp;
+			GnmParsePos pp;
 			char *p;
 
 			pp.wb = state->wb;
@@ -630,7 +631,7 @@ qpro_parse_formula (QProReadState *state, int col, int row,
 	gnm_expr_unref (expr);
 }
 
-static MStyle *
+static GnmStyle *
 qpro_get_style (QProReadState *state, guint8 const *data)
 {
 #if 0
@@ -827,7 +828,7 @@ qpro_file_open (GnmFileOpener const *fo, IOContext *context,
 {
 	QProReadState state;
 	GsfInput *stream = NULL;
-	GsfInfile *ole;
+	GsfInfileMSOle *ole;
 
 	state.io_context = context;
 	state.wbv = new_wb_view;
@@ -838,7 +839,8 @@ qpro_file_open (GnmFileOpener const *fo, IOContext *context,
 	/* check for >= QPro 6.0 which is OLE based */
 	ole = gsf_infile_msole_new (input, NULL);
 	if (ole != NULL) {
-		stream = gsf_infile_child_by_name (ole, "PerfectOffice_MAIN");
+		stream = gsf_infile_child_by_name (GSF_INFILE (ole),
+						   "PerfectOffice_MAIN");
 		if (stream != NULL) {
 			qpro_read_workbook (&state, stream);
 			g_object_unref (G_OBJECT (stream));
