@@ -37,6 +37,9 @@
 #include <workbook-cmd-format.h>
 
 #include <glade/glade.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtklabel.h>
 
 #define COL_WIDTH_DIALOG_KEY "col-width-dialog"
 
@@ -130,7 +133,7 @@ dialog_col_width_load_value (ColWidthState *state)
 		value = sheet_col_get_default_size_pts (state->sheet);
 	} else {
 		for (l = state->sv->selections; l; l = l->next){
-			Range *ss = l->data;
+			GnmRange *ss = l->data;
 			int col;
 
 			for (col = ss->start.col; col <= ss->end.col; col++){
@@ -187,7 +190,7 @@ cb_dialog_col_width_apply_clicked (G_GNUC_UNUSED GtkWidget *button,
 	gnm_float value = gtk_spin_button_get_value (state->spin);
 	double const scale =
 		state->sheet->last_zoom_factor_used *
-		application_display_dpi_get (FALSE) / 72.;
+		gnm_app_display_dpi_get (FALSE) / 72.;
 	int size_pixels = (int)(value * scale + 0.5);
 	gboolean use_default = gtk_toggle_button_get_active
 		(GTK_TOGGLE_BUTTON (state->default_check));
@@ -251,7 +254,7 @@ dialog_col_width (WorkbookControlGUI *wbcg, gboolean use_default)
 
 	if (gnumeric_dialog_raise_if_exists (wbcg, COL_WIDTH_DIALOG_KEY))
 		return;
-	gui = gnm_glade_xml_new (COMMAND_CONTEXT (wbcg),
+	gui = gnm_glade_xml_new (GNM_CMD_CONTEXT (wbcg),
 		"col-width.glade", NULL, NULL);
 	if (gui == NULL)
 		return;
