@@ -91,7 +91,7 @@ gnm_pane_init (GnumericPane *pane, SheetControlGUI *scg,
 	FooCanvasItem	 *item;
 	FooCanvasGroup *gcanvas_group;
 	Sheet *sheet;
-	Range r;
+	GnmRange r;
 	int i;
 
 	g_return_if_fail (!pane->is_active);
@@ -143,7 +143,8 @@ gnm_pane_init (GnumericPane *pane, SheetControlGUI *scg,
 			sheet_object_new_view (ptr->data, SHEET_CONTROL (scg),
 					       (gpointer)pane);
 	}
-	pane->cursor_type = GNM_CURSOR_FAT_CROSS;
+
+	pane->mouse_cursor = NULL;
 }
 
 void
@@ -170,6 +171,11 @@ gnm_pane_release (GnumericPane *pane)
 		pane->anted_cursors = NULL;
 	}
 
+	if (pane->mouse_cursor) {
+		gdk_cursor_unref (pane->mouse_cursor);
+		pane->mouse_cursor = NULL;
+	}
+
 	/* Be anal just in case we somehow manage to remove a pane
 	 * unexpectedly.
 	 */
@@ -186,7 +192,7 @@ gnm_pane_bound_set (GnumericPane *pane,
 		    int start_col, int start_row,
 		    int end_col, int end_row)
 {
-	Range r;
+	GnmRange r;
 
 	g_return_if_fail (pane != NULL);
 	g_return_if_fail (pane->gcanvas != NULL);
@@ -318,7 +324,7 @@ gnm_pane_reposition_cursors (GnumericPane *pane)
 }
 
 gboolean
-gnm_pane_cursor_bound_set (GnumericPane *pane, Range const *r)
+gnm_pane_cursor_bound_set (GnumericPane *pane, GnmRange const *r)
 {
 	return item_cursor_bound_set (pane->cursor.std, r);
 }
@@ -326,12 +332,12 @@ gnm_pane_cursor_bound_set (GnumericPane *pane, Range const *r)
 /****************************************************************************/
 
 gboolean
-gnm_pane_rangesel_bound_set (GnumericPane *pane, Range const *r)
+gnm_pane_rangesel_bound_set (GnumericPane *pane, GnmRange const *r)
 {
 	return item_cursor_bound_set (pane->cursor.rangesel, r);
 }
 void
-gnm_pane_rangesel_start (GnumericPane *pane, Range const *r)
+gnm_pane_rangesel_start (GnumericPane *pane, GnmRange const *r)
 {
 	FooCanvas *canvas = FOO_CANVAS (pane->gcanvas);
 	FooCanvasItem *tmp;
@@ -380,7 +386,7 @@ gnm_pane_rangesel_stop (GnumericPane *pane)
 /****************************************************************************/
 
 gboolean
-gnm_pane_special_cursor_bound_set (GnumericPane *pane, Range const *r)
+gnm_pane_special_cursor_bound_set (GnumericPane *pane, GnmRange const *r)
 {
 	return item_cursor_bound_set (pane->cursor.special, r);
 }
@@ -411,6 +417,15 @@ gnm_pane_special_cursor_stop (GnumericPane *pane)
 	pane->cursor.special = NULL;
 }
 
+void
+gnm_pane_mouse_cursor_set (GnumericPane *pane, GdkCursor *c)
+{
+	gdk_cursor_ref (c);
+	if (pane->mouse_cursor)
+		gdk_cursor_unref (pane->mouse_cursor);
+	pane->mouse_cursor = c;
+}
+
 /****************************************************************************/
 
 void
@@ -418,7 +433,7 @@ gnm_pane_edit_start (GnumericPane *pane)
 {
 	GnmCanvas const *gcanvas = pane->gcanvas;
 	SheetView const *sv = sc_view (SHEET_CONTROL (gcanvas->simple.scg));
-	CellPos const *edit_pos;
+	GnmCellPos const *edit_pos;
 
 	g_return_if_fail (pane->editor == NULL);
 
@@ -577,8 +592,10 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
 
 	switch (event->type) {
 	case GDK_ENTER_NOTIFY: {
-		gpointer p = g_object_get_data (G_OBJECT (ctrl_pt), "cursor");
-		gnm_cursor_set_widget (GTK_WIDGET (ctrl_pt->canvas), GPOINTER_TO_UINT (p));
+		GdkCursorType ct = GPOINTER_TO_UINT
+			(g_object_get_data (G_OBJECT (ctrl_pt), "cursor"));
+		gnm_widget_set_cursor_type (GTK_WIDGET (ctrl_pt->canvas), ct);
+
 		if (pane->control_points [8] != ctrl_pt)
 			foo_canvas_item_set (ctrl_pt,
 				"fill_color",    "green",
@@ -678,7 +695,7 @@ cb_control_point_event (FooCanvasItem *ctrl_pt, GdkEvent *event,
  **/
 static FooCanvasItem *
 new_control_point (GObject *so_view, int idx, double x, double y,
-		   GnmCursorType ct)
+		   GdkCursorType ct)
 {
 	FooCanvasItem *item, *so_view_item = FOO_CANVAS_ITEM (so_view);
 	GnmCanvas *gcanvas = GNM_CANVAS (so_view_item->canvas);
@@ -709,7 +726,7 @@ new_control_point (GObject *so_view, int idx, double x, double y,
  */
 static void
 set_item_x_y (GnumericPane *pane, GObject *so_view, int idx,
-	      double x, double y, GnmCursorType ct, gboolean visible)
+	      double x, double y, GdkCursorType ct, gboolean visible)
 {
 	if (pane->control_points [idx] == NULL)
 		pane->control_points [idx] = new_control_point (
@@ -764,12 +781,12 @@ set_acetate_coords (GnumericPane *pane, GObject *so_view,
 			NULL);
 		g_object_unref (stipple);
 		g_signal_connect (G_OBJECT (item),
-			"event",
-			G_CALLBACK (cb_control_point_event), so_view);
+				  "event",
+				  G_CALLBACK (cb_control_point_event), so_view);
 		g_object_set_data (G_OBJECT (item), "index",
-			GINT_TO_POINTER (8));
+				   GINT_TO_POINTER (8));
 		g_object_set_data (G_OBJECT (item), "cursor",
-			GINT_TO_POINTER (GNM_CURSOR_MOVE));
+				   GINT_TO_POINTER (GDK_FLEUR));
 
 		pane->control_points [8] = item;
 	}
@@ -796,21 +813,21 @@ gnm_pane_object_set_bounds (GnumericPane *pane, SheetObject *so,
 	set_acetate_coords (pane, so_view_obj, l, t, r, b);
 
 	set_item_x_y (pane, so_view_obj, 0, l, t,
-		      GNM_CURSOR_SIZE_TL, TRUE);
+		      GDK_SIZING /* L */, TRUE);
 	set_item_x_y (pane, so_view_obj, 1, (l + r) / 2, t,
-		      GNM_CURSOR_SIZE_Y, fabs (r-l) >= CTRL_PT_TOTAL_SIZE);
+		      GDK_SB_V_DOUBLE_ARROW, fabs (r-l) >= CTRL_PT_TOTAL_SIZE);
 	set_item_x_y (pane, so_view_obj, 2, r, t,
-		      GNM_CURSOR_SIZE_TR, TRUE);
+		      GDK_SIZING /* R */, TRUE);
 	set_item_x_y (pane, so_view_obj, 3, l, (t + b) / 2,
-		      GNM_CURSOR_SIZE_X, fabs (b-t) >= CTRL_PT_TOTAL_SIZE);
+		      GDK_SB_H_DOUBLE_ARROW, fabs (b-t) >= CTRL_PT_TOTAL_SIZE);
 	set_item_x_y (pane, so_view_obj, 4, r, (t + b) / 2,
-		      GNM_CURSOR_SIZE_X, fabs (b-t) >= CTRL_PT_TOTAL_SIZE);
+		      GDK_SB_H_DOUBLE_ARROW, fabs (b-t) >= CTRL_PT_TOTAL_SIZE);
 	set_item_x_y (pane, so_view_obj, 5, l, b,
-		      GNM_CURSOR_SIZE_TR, TRUE);
+		      GDK_SIZING /* R */, TRUE);
 	set_item_x_y (pane, so_view_obj, 6, (l + r) / 2, b,
-		      GNM_CURSOR_SIZE_Y, fabs (r-l) >= CTRL_PT_TOTAL_SIZE);
+		      GDK_SB_V_DOUBLE_ARROW, fabs (r-l) >= CTRL_PT_TOTAL_SIZE);
 	set_item_x_y (pane, so_view_obj, 7, r, b,
-		      GNM_CURSOR_SIZE_TL, TRUE);
+		      GDK_SIZING /* L */, TRUE);
 }
 
 static int
@@ -821,9 +838,10 @@ cb_sheet_object_canvas_event (FooCanvasItem *item, GdkEvent *event,
 
 	switch (event->type) {
 	case GDK_ENTER_NOTIFY:
-		gnm_cursor_set_widget (GTK_WIDGET (item->canvas),
-			(so->type == SHEET_OBJECT_ACTION_STATIC)
-			? GNM_CURSOR_ARROW : GNM_CURSOR_PRESS);
+		gnm_widget_set_cursor_type (GTK_WIDGET (item->canvas),
+					    (so->type == SHEET_OBJECT_ACTION_STATIC)
+					    ? GDK_ARROW
+					    : GDK_HAND2);
 		break;
 
 	case GDK_BUTTON_PRESS: {
