@@ -45,6 +45,15 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gsf/gsf-impl-utils.h>
+#include <gtk/gtkframe.h>
+#include <gtk/gtkalignment.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkrange.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkhscrollbar.h>
+#include <gtk/gtkvscrollbar.h>
+#include <gtk/gtkvbox.h>
 
 #include <string.h>
 
@@ -96,7 +105,7 @@ scg_redraw_all (SheetControl *sc, gboolean headers)
 }
 
 static void
-scg_redraw_range (SheetControl *sc, Range const *r)
+scg_redraw_range (SheetControl *sc, GnmRange const *r)
 {
 	SheetControlGUI *scg = (SheetControlGUI *)sc;
 
@@ -113,7 +122,7 @@ scg_redraw_range (SheetControl *sc, Range const *r)
 static void
 scg_redraw_headers (SheetControl *sc,
 		    gboolean const col, gboolean const row,
-		    Range const * r /* optional == NULL */)
+		    GnmRange const * r /* optional == NULL */)
 {
 	SheetControlGUI *scg = (SheetControlGUI *)sc;
 	GnumericPane *pane;
@@ -291,8 +300,8 @@ scg_resize (SheetControl *sc, gboolean force_scroll)
 		foo_canvas_set_scroll_region (scg->pane[0].row.canvas,
 			0, 0, w / zoom, GNUMERIC_CANVAS_FACTOR_Y / zoom);
 	} else {
-		CellPos const *tl = &sc->view->frozen_top_left;
-		CellPos const *br = &sc->view->unfrozen_top_left;
+		GnmCellPos const *tl = &sc->view->frozen_top_left;
+		GnmCellPos const *br = &sc->view->unfrozen_top_left;
 		int const l = scg_colrow_distance_get (scg, TRUE,
 			0, tl->col);
 		int const r = scg_colrow_distance_get (scg, TRUE,
@@ -679,7 +688,7 @@ void
 scg_set_left_col (SheetControlGUI *scg, int col)
 {
 	Sheet const *sheet;
-	Range const *bound;
+	GnmRange const *bound;
 
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 
@@ -739,7 +748,7 @@ void
 scg_set_top_row (SheetControlGUI *scg, int row)
 {
 	Sheet const *sheet;
-	Range const *bound;
+	GnmRange const *bound;
 
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 
@@ -817,7 +826,7 @@ gnm_canvas_make_cell_visible (GnmCanvas *gcanvas, int col, int row,
 	Sheet *sheet;
 	int   new_first_col, new_first_row;
 
-	g_return_if_fail (GNM_IS_CANVAS (gcanvas));
+	g_return_if_fail (IS_GNM_CANVAS (gcanvas));
 
 	/* Avoid calling this before the canvas is realized: We do not know the
 	 * visible area, and would unconditionally scroll the cell to the top
@@ -903,7 +912,7 @@ scg_make_cell_visible (SheetControlGUI *scg, int col, int row,
 		       gboolean force_scroll, gboolean couple_panes)
 {
 	SheetView const *sv = ((SheetControl *) scg)->view;
-	CellPos const *tl, *br;
+	GnmCellPos const *tl, *br;
 
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 
@@ -987,8 +996,8 @@ scg_set_panes (SheetControl *sc)
 		return;
 
 	if (being_frozen) {
-		CellPos const *tl = &sc->view->frozen_top_left;
-		CellPos const *br = &sc->view->unfrozen_top_left;
+		GnmCellPos const *tl = &sc->view->frozen_top_left;
+		GnmCellPos const *br = &sc->view->unfrozen_top_left;
 		gboolean const freeze_h = br->col > tl->col;
 		gboolean const freeze_v = br->row > tl->row;
 
@@ -1069,7 +1078,7 @@ scg_set_panes (SheetControl *sc)
 	scg_resize (SHEET_CONTROL (scg), TRUE);
 
 	if (being_frozen) {
-		CellPos const *tl = &sc->view->frozen_top_left;
+		GnmCellPos const *tl = &sc->view->frozen_top_left;
 
 		if (scg->pane[1].is_active)
 			gnm_canvas_set_left_col (scg->pane[1].gcanvas, tl->col);
@@ -1150,7 +1159,7 @@ sheet_control_gui_new (SheetView *sv, WorkbookControlGUI *wbcg)
 	gtk_widget_show_all (GTK_WIDGET (scg->inner_table));
 
 	/* Scroll bars and their adjustments */
-	scroll_update_policy = application_live_scrolling ()
+	scroll_update_policy = gnm_app_live_scrolling ()
 		? GTK_UPDATE_CONTINUOUS : GTK_UPDATE_DELAYED;
 	scg->va = gtk_adjustment_new (0., 0., 1, 1., 1., 1.);
 	scg->vs = g_object_new (GTK_TYPE_VSCROLLBAR,
@@ -1284,7 +1293,7 @@ scg_ant (SheetControl *sc)
 		scg_unant (sc);
 
 	for (l = sc->view->ants; l; l = l->next) {
-		Range const *r = l->data;
+		GnmRange const *r = l->data;
 
 		SCG_FOREACH_PANE (scg, pane, {
 			ItemCursor *ic = ITEM_CURSOR (foo_canvas_item_new (
@@ -1341,10 +1350,10 @@ scg_adjust_preferences (SheetControl *sc)
 	}
 }
 
-StyleFont *
+GnmFont *
 scg_get_style_font (PangoContext *context,
 		    Sheet const *sheet,
-		    MStyle const *mstyle)
+		    GnmStyle const *mstyle)
 {
 	/* When previewing sheet can == NULL */
 	double const zoom = (sheet) ? sheet->last_zoom_factor_used : 1.;
@@ -1441,7 +1450,7 @@ context_menu_handler (GnumericPopupMenuElement const *element,
 		break;
 
 	case CONTEXT_HYPERLINK_REMOVE: {
-		MStyle *style = mstyle_new ();
+		GnmStyle *style = mstyle_new ();
 		mstyle_set_hlink (style, NULL);
 		cmd_selection_format (wbc, style, NULL,
 			_("Remove Hyperlink"));
@@ -1555,8 +1564,8 @@ scg_context_menu (SheetControlGUI *scg, GdkEventButton *event,
 	 * items
 	 */
 	int sensitivity_filter =
-		(!application_clipboard_is_empty () &&
-		!application_clipboard_is_cut ())
+		(!gnm_app_clipboard_is_empty () &&
+		!gnm_app_clipboard_is_cut ())
 		? 0 : CONTEXT_DISABLE_PASTE_SPECIAL;
 
 	GList *l;
@@ -1569,7 +1578,7 @@ scg_context_menu (SheetControlGUI *scg, GdkEventButton *event,
 	 * accordingly
 	 */
 	for (l = sc->view->selections; l != NULL; l = l->next) {
-		Range const *r = l->data;
+		GnmRange const *r = l->data;
 
 		if (r->start.row == 0 && r->end.row == SHEET_MAX_ROWS - 1)
 			sensitivity_filter |= CONTEXT_DISABLE_FOR_ROWS;
@@ -1591,7 +1600,7 @@ scg_context_menu (SheetControlGUI *scg, GdkEventButton *event,
 }
 
 static gboolean
-cb_redraw_sel (SheetView *sv, Range const *r, gpointer user_data)
+cb_redraw_sel (SheetView *sv, GnmRange const *r, gpointer user_data)
 {
 	SheetControl *sc = user_data;
 	scg_redraw_range (sc, r);
@@ -1913,7 +1922,7 @@ scg_object_view_position (SheetControlGUI *scg, SheetObject *so, double *coords)
  *
  */
 void
-scg_comment_display (SheetControlGUI *scg, CellComment *cc)
+scg_comment_display (SheetControlGUI *scg, GnmComment *cc)
 {
 	int x, y;
 
@@ -1999,7 +2008,7 @@ cb_cell_comment_timer (SheetControlGUI *scg)
  * Prepare @cc for display.
  */
 void
-scg_comment_select (SheetControlGUI *scg, CellComment *cc)
+scg_comment_select (SheetControlGUI *scg, GnmComment *cc)
 {
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 	g_return_if_fail (scg->comment.timer == -1);
@@ -2021,7 +2030,7 @@ scg_comment_select (SheetControlGUI *scg, CellComment *cc)
  * display mechanism.
  */
 void
-scg_comment_unselect (SheetControlGUI *scg, CellComment *cc)
+scg_comment_unselect (SheetControlGUI *scg, GnmComment *cc)
 {
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 
@@ -2106,7 +2115,7 @@ scg_colrow_distance_get_virtual (SheetControl const *sc, gboolean is_cols,
 /*************************************************************************/
 
 static void
-scg_cursor_bound (SheetControl *sc, Range const *r)
+scg_cursor_bound (SheetControl *sc, GnmRange const *r)
 {
 	SheetControlGUI *scg = (SheetControlGUI *) sc;
 	SCG_FOREACH_PANE (scg, pane, gnm_pane_cursor_bound_set (pane, r););
@@ -2152,7 +2161,7 @@ scg_rangesel_changed (SheetControlGUI *scg,
 {
 	GnmExprEntry *expr_entry;
 	gboolean ic_changed;
-	Range *r, last_r;
+	GnmRange *r, last_r;
 	Sheet *sheet;
 
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
@@ -2208,7 +2217,7 @@ scg_rangesel_start (SheetControlGUI *scg,
 		    int base_col, int base_row,
 		    int move_col, int move_row)
 {
-	Range r;
+	GnmRange r;
 
 	g_return_if_fail (IS_SHEET_CONTROL_GUI (scg));
 
@@ -2313,7 +2322,7 @@ scg_rangesel_move (SheetControlGUI *scg, int n, gboolean jump_to_bound,
 		   gboolean horiz)
 {
 	SheetView *sv = sc_view ((SheetControl *) scg);
-	CellPos tmp;
+	GnmCellPos tmp;
 
 	if (!scg->rangesel.active) {
 		tmp.col = sv->edit_pos_real.col;
@@ -2344,7 +2353,7 @@ scg_rangesel_extend (SheetControlGUI *scg, int n,
 	Sheet *sheet = ((SheetControl *) scg)->sheet;
 
 	if (scg->rangesel.active) {
-		CellPos tmp = scg->rangesel.move_corner;
+		GnmCellPos tmp = scg->rangesel.move_corner;
 
 		if (horiz)
 			tmp.col = sheet_find_boundary_horizontal (sheet,
@@ -2384,7 +2393,7 @@ scg_cursor_move (SheetControlGUI *scg, int n,
 		 gboolean jump_to_bound, gboolean horiz)
 {
 	SheetView *sv = sc_view ((SheetControl *) scg);
-	CellPos tmp = sv->edit_pos_real;
+	GnmCellPos tmp = sv->edit_pos_real;
 
 	if (!wbcg_edit_finish (scg->wbcg, TRUE, NULL))
 		return;
@@ -2401,7 +2410,7 @@ scg_cursor_move (SheetControlGUI *scg, int n,
 	sv_selection_reset (sv);
 	sv_cursor_set (sv, &tmp,
 		       tmp.col, tmp.row, tmp.col, tmp.row, NULL);
-	sv_make_cell_visible (sv, tmp.col, tmp.row, TRUE);
+	sv_make_cell_visible (sv, tmp.col, tmp.row, FALSE);
 	sv_selection_add_pos (sv, tmp.col, tmp.row);
 }
 
@@ -2418,8 +2427,8 @@ scg_cursor_extend (SheetControlGUI *scg, int n,
 		   gboolean jump_to_bound, gboolean horiz)
 {
 	SheetView *sv = ((SheetControl *) scg)->view;
-	CellPos move = sv->cursor.move_corner;
-	CellPos visible = scg->pane[0].gcanvas->first;
+	GnmCellPos move = sv->cursor.move_corner;
+	GnmCellPos visible = scg->pane[0].gcanvas->first;
 
 	if (horiz)
 		visible.col = move.col = sheet_find_boundary_horizontal (sv->sheet,
@@ -2502,7 +2511,7 @@ scg_special_cursor_stop (SheetControlGUI *scg)
 }
 
 gboolean
-scg_special_cursor_bound_set (SheetControlGUI *scg, Range const *r)
+scg_special_cursor_bound_set (SheetControlGUI *scg, GnmRange const *r)
 {
 	gboolean changed = FALSE;
 
@@ -2568,10 +2577,15 @@ GSF_CLASS (SheetControlGUI, sheet_control_gui,
 static gint
 cb_scg_queued_movement (SheetControlGUI *scg)
 {
+	Sheet const *sheet = ((SheetControl *)scg)->sheet;
 	scg->delayedMovement.timer = -1;
 	(*scg->delayedMovement.handler) (scg,
 		scg->delayedMovement.n, FALSE,
 		scg->delayedMovement.horiz);
+	if (wbcg_is_editing (scg->wbcg))
+		sheet_update_only_grid (sheet);
+	else
+		sheet_update (sheet);
 	return FALSE;
 }
 
@@ -2616,7 +2630,12 @@ scg_queue_movement (SheetControlGUI	*scg,
 
 	/* jumps are always immediate */
 	if (jump) {
+		Sheet const *sheet = ((SheetControl *)scg)->sheet;
 		(*handler) (scg, n, TRUE, horiz);
+		if (wbcg_is_editing (scg->wbcg))
+			sheet_update_only_grid (sheet);
+		else
+			sheet_update (sheet);
 		return;
 	}
 
