@@ -43,8 +43,8 @@ typedef union _CellTile CellTile;
 struct _SheetStyleData {
 	GHashTable *style_hash;
 	CellTile   *styles;
-	MStyle	   *default_style;
-	StyleColor *auto_pattern_color;
+	GnmStyle	   *default_style;
+	GnmColor *auto_pattern_color;
 };
 
 /**
@@ -52,7 +52,7 @@ struct _SheetStyleData {
  * For internal use only
  */
 void
-sheet_style_unlink (Sheet *sheet, MStyle *st)
+sheet_style_unlink (Sheet *sheet, GnmStyle *st)
 {
 	if (sheet->style_data->style_hash != NULL)
 		g_hash_table_remove (sheet->style_data->style_hash, st);
@@ -67,10 +67,10 @@ sheet_style_unlink (Sheet *sheet, MStyle *st)
  * Looks up a style from the sheets collection.  Linking if necessary.
  * ABSORBS the reference and adds a link.
  */
-static MStyle *
-sheet_style_find (Sheet *sheet, MStyle *s)
+static GnmStyle *
+sheet_style_find (Sheet *sheet, GnmStyle *s)
 {
-	MStyle *res;
+	GnmStyle *res;
 	res = g_hash_table_lookup (sheet->style_data->style_hash, s);
 	if (res != NULL) {
 		mstyle_link (res);
@@ -85,7 +85,7 @@ sheet_style_find (Sheet *sheet, MStyle *s)
 
 /* Place holder until I merge in the new styles too */
 static void
-pstyle_set_border (MStyle *st, StyleBorder *border,
+pstyle_set_border (GnmStyle *st, GnmBorder *border,
 		   StyleBorderLocation side)
 {
 	mstyle_set_border (st, MSTYLE_BORDER_TOP + side,
@@ -96,14 +96,14 @@ pstyle_set_border (MStyle *st, StyleBorder *border,
  * by caching and rereferencing the merged result for repeated styles.
  */
 typedef struct {
-	MStyle	   *new_style;
-	MStyle	   *pstyle;
+	GnmStyle	   *new_style;
+	GnmStyle	   *pstyle;
 	GHashTable *cache;
 	Sheet	   *sheet;
 } ReplacementStyle;
 
 static ReplacementStyle *
-rstyle_ctor (ReplacementStyle *res, MStyle *new_style, MStyle *pstyle, Sheet *sheet)
+rstyle_ctor (ReplacementStyle *res, GnmStyle *new_style, GnmStyle *pstyle, Sheet *sheet)
 {
 	res->sheet = sheet;
 	if (new_style != NULL) {
@@ -121,8 +121,8 @@ rstyle_ctor (ReplacementStyle *res, MStyle *new_style, MStyle *pstyle, Sheet *sh
 static void
 cb_style_unlink (gpointer key, gpointer value, gpointer user_data)
 {
-	mstyle_unlink ((MStyle *)key);
-	mstyle_unlink ((MStyle *)value);
+	mstyle_unlink ((GnmStyle *)key);
+	mstyle_unlink ((GnmStyle *)value);
 }
 
 static void
@@ -149,9 +149,9 @@ rstyle_dtor (ReplacementStyle *rs)
  * and will maintain the cache of styles associated with each sheet
  */
 static void
-rstyle_apply (MStyle **old, ReplacementStyle *rs)
+rstyle_apply (GnmStyle **old, ReplacementStyle *rs)
 {
-	MStyle *s;
+	GnmStyle *s;
 	g_return_if_fail (old != NULL);
 	g_return_if_fail (rs != NULL);
 
@@ -159,9 +159,9 @@ rstyle_apply (MStyle **old, ReplacementStyle *rs)
 		/* Cache the merged styles keeping a reference to the originals
 		 * just in case all instances change.
 		 */
-		s = (MStyle *)g_hash_table_lookup (rs->cache, *old);
+		s = (GnmStyle *)g_hash_table_lookup (rs->cache, *old);
 		if (s == NULL) {
-			MStyle *tmp = mstyle_copy_merge (*old, rs->pstyle);
+			GnmStyle *tmp = mstyle_copy_merge (*old, rs->pstyle);
 			s = sheet_style_find (rs->sheet, tmp);
 			mstyle_link (*old);
 			g_hash_table_insert (rs->cache, *old, s);
@@ -239,19 +239,19 @@ static int const tile_heights [] = {
 
 typedef struct {
 	CellTileType const type;
-	MStyle *style [1];
+	GnmStyle *style [1];
 } CellTileStyleSimple;
 typedef struct {
 	CellTileType const type;
-	MStyle *style [TILE_SIZE_COL];
+	GnmStyle *style [TILE_SIZE_COL];
 } CellTileStyleCol;
 typedef struct {
 	CellTileType const type;
-	MStyle *style [TILE_SIZE_ROW];
+	GnmStyle *style [TILE_SIZE_ROW];
 } CellTileStyleRow;
 typedef struct {
 	CellTileType const type;
-	MStyle *style [TILE_SIZE_COL * TILE_SIZE_ROW];
+	GnmStyle *style [TILE_SIZE_COL * TILE_SIZE_ROW];
 } CellTileStyleMatrix;
 typedef struct {
 	CellTileType const type;
@@ -270,7 +270,7 @@ union _CellTile {
 
 #if USE_TILE_POOLS
 static int tile_pool_users;
-static gnm_mem_chunk *tile_pools[5];
+static GnmMemChunk *tile_pools[5];
 #define CHUNK_ALLOC(T,p) ((T*)gnm_mem_chunk_alloc (p))
 #define CHUNK_FREE(p,v) gnm_mem_chunk_free ((p), (v))
 #else
@@ -308,7 +308,7 @@ cell_tile_dtor (CellTile *tile)
 }
 
 static CellTile *
-cell_tile_style_new (MStyle *style, CellTileType t)
+cell_tile_style_new (GnmStyle *style, CellTileType t)
 {
 	CellTile *res;
 
@@ -396,11 +396,11 @@ cell_tile_ptr_matrix_new (CellTile *t)
 }
 
 static CellTile *
-cell_tile_matrix_set (CellTile *t, Range const *indic, ReplacementStyle *rs)
+cell_tile_matrix_set (CellTile *t, GnmRange const *indic, ReplacementStyle *rs)
 {
 	int i, r, c;
 	CellTileStyleMatrix *res;
-	MStyle *tmp;
+	GnmStyle *tmp;
 
 	g_return_val_if_fail (t != NULL, NULL);
 	g_return_val_if_fail (TILE_SIMPLE <= t->type &&
@@ -440,7 +440,7 @@ cell_tile_matrix_set (CellTile *t, Range const *indic, ReplacementStyle *rs)
 		cell_tile_dtor (t);
 
 	if (indic != NULL) {
-		MStyle **style = res->style;
+		GnmStyle **style = res->style;
 		r = indic->start.row;
 		style += r*TILE_SIZE_COL;
 		for ( ;r <= indic->end.row ; ++r, style += TILE_SIZE_COL)
@@ -498,10 +498,10 @@ sheet_style_init (Sheet *sheet)
 	sheet->style_data = g_new (SheetStyleData, 1);
 	sheet->style_data->style_hash =
 		g_hash_table_new (mstyle_hash, (GCompareFunc) mstyle_equal);
-#warning "FIXME: Allocating a StyleColor here is dubious."
-	sheet->style_data->auto_pattern_color = g_new (StyleColor, 1);
+#warning "FIXME: Allocating a GnmColor here is dubious."
+	sheet->style_data->auto_pattern_color = g_new (GnmColor, 1);
 	memcpy (sheet->style_data->auto_pattern_color,
-		style_color_auto_pattern (), sizeof (StyleColor));
+		style_color_auto_pattern (), sizeof (GnmColor));
 	sheet->style_data->auto_pattern_color->ref_count = 1;
 	sheet->style_data->default_style =
 		sheet_style_find (sheet, mstyle_new_default ());
@@ -591,9 +591,9 @@ sheet_style_shutdown (Sheet *sheet)
  * Set the color for rendering auto colored patterns in this sheet.
  */
 void
-sheet_style_set_auto_pattern_color (Sheet  *sheet, StyleColor *pattern_color)
+sheet_style_set_auto_pattern_color (Sheet  *sheet, GnmColor *pattern_color)
 {
-	StyleColor *apc;
+	GnmColor *apc;
 	int ref_count;
 
 	g_return_if_fail (IS_SHEET (sheet));
@@ -601,7 +601,7 @@ sheet_style_set_auto_pattern_color (Sheet  *sheet, StyleColor *pattern_color)
 
 	apc = sheet->style_data->auto_pattern_color;
 	ref_count = apc->ref_count;
-	memcpy(apc, pattern_color, sizeof (StyleColor));
+	memcpy(apc, pattern_color, sizeof (GnmColor));
 	apc->is_auto = TRUE;
 	apc->ref_count = ref_count;
 	style_color_unref (pattern_color);
@@ -614,10 +614,10 @@ sheet_style_set_auto_pattern_color (Sheet  *sheet, StyleColor *pattern_color)
  *
  * Returns the color for rendering auto colored patterns in this sheet.
  */
-StyleColor *
+GnmColor *
 sheet_style_get_auto_pattern_color (Sheet const *sheet)
 {
-	StyleColor *sc;
+	GnmColor *sc;
 	g_return_val_if_fail (IS_SHEET (sheet), style_color_black ());
 	g_return_val_if_fail (sheet->style_data != NULL, style_color_black ());
 	g_return_val_if_fail (sheet->style_data->auto_pattern_color != NULL,
@@ -642,10 +642,10 @@ sheet_style_get_auto_pattern_color (Sheet const *sheet)
 void
 sheet_style_update_grid_color (Sheet const *sheet)
 {
-	StyleColor *default_auto = style_color_auto_pattern ();
-	StyleColor *sheet_auto = sheet_style_get_auto_pattern_color (sheet);
-	StyleColor *grid_color = style_color_grid ();
-	StyleColor *new_color;
+	GnmColor *default_auto = style_color_auto_pattern ();
+	GnmColor *sheet_auto = sheet_style_get_auto_pattern_color (sheet);
+	GnmColor *grid_color = style_color_grid ();
+	GnmColor *new_color;
 
 	new_color = (style_color_equal (default_auto, sheet_auto)
 		     ? grid_color : sheet_auto);
@@ -662,11 +662,11 @@ sheet_style_update_grid_color (Sheet const *sheet)
 
 /****************************************************************************/
 
-static MStyle *
-vector_apply_pstyle (MStyle **styles, int n, ReplacementStyle *rs)
+static GnmStyle *
+vector_apply_pstyle (GnmStyle **styles, int n, ReplacementStyle *rs)
 {
 	gboolean is_uniform = TRUE;
-	MStyle *prev = NULL;
+	GnmStyle *prev = NULL;
 
 	while (--n >= 0) {
 		rstyle_apply (styles + n, rs);
@@ -681,7 +681,7 @@ vector_apply_pstyle (MStyle **styles, int n, ReplacementStyle *rs)
 }
 
 static gboolean
-col_indicies (int corner_col, int w, Range const *apply_to,
+col_indicies (int corner_col, int w, GnmRange const *apply_to,
 	      int *first_index, int *last_index)
 {
 	int i, tmp;
@@ -702,7 +702,7 @@ col_indicies (int corner_col, int w, Range const *apply_to,
 }
 
 static gboolean
-row_indicies (int corner_row, int h, Range const *apply_to,
+row_indicies (int corner_row, int h, GnmRange const *apply_to,
 	      int *first_index, int *last_index)
 {
 	int i, tmp;
@@ -729,7 +729,7 @@ row_indicies (int corner_row, int h, Range const *apply_to,
 static void
 cell_tile_apply (CellTile **tile, int level,
 		 int corner_col, int corner_row,
-		 Range const *apply_to,
+		 GnmRange const *apply_to,
 		 ReplacementStyle *rs)
 {
 	int const width = tile_widths [level+1];
@@ -740,7 +740,7 @@ cell_tile_apply (CellTile **tile, int level,
 				     apply_to->end.col >= (corner_col+width-1));
 	gboolean const full_height = (apply_to->start.row <= corner_row &&
 				      apply_to->end.row >= (corner_row+height-1));
-	Range indic;
+	GnmRange indic;
 	CellTile *res = NULL;
 	CellTileType type;
 	int c, r, i;
@@ -770,7 +770,7 @@ cell_tile_apply (CellTile **tile, int level,
 			*tile = res;
 		}
 		if (TILE_SIMPLE <= type && type <= TILE_MATRIX) {
-			MStyle *uniform = vector_apply_pstyle (
+			GnmStyle *uniform = vector_apply_pstyle (
 				(*tile)->style_any.style, tile_size [type], rs);
 			if (uniform == NULL)
 				return;
@@ -873,10 +873,10 @@ cell_tile_apply (CellTile **tile, int level,
 static void
 foreach_tile (CellTile *tile, int level,
 	      int corner_col, int corner_row,
-	      Range const *apply_to,
-	      void (*handler) (MStyle *style,
+	      GnmRange const *apply_to,
+	      void (*handler) (GnmStyle *style,
 			       int corner_col, int corner_row, int width, int height,
-			       Range const *apply_to, gpointer user),
+			       GnmRange const *apply_to, gpointer user),
 	      gpointer user)
 {
 	int const width = tile_widths [level+1];
@@ -1034,8 +1034,8 @@ tail_recursion :
  * This function absorbs a reference to the new @style.
  */
 void
-sheet_style_set_range (Sheet *sheet, Range const *range,
-		       MStyle *style)
+sheet_style_set_range (Sheet *sheet, GnmRange const *range,
+		       GnmStyle *style)
 {
 	ReplacementStyle rs;
 
@@ -1061,7 +1061,7 @@ sheet_style_set_range (Sheet *sheet, Range const *range,
  */
 void
 sheet_style_set_pos (Sheet *sheet, int col, int row,
-		     MStyle *style)
+		     GnmStyle *style)
 {
 	ReplacementStyle rs;
 
@@ -1079,7 +1079,7 @@ sheet_style_set_pos (Sheet *sheet, int col, int row,
  *
  * Returns a reference to default style for a sheet.
  */
-MStyle *
+GnmStyle *
 sheet_style_default (Sheet const *sheet)
 {
 	g_return_val_if_fail (IS_SHEET (sheet), NULL);
@@ -1098,7 +1098,7 @@ sheet_style_default (Sheet const *sheet)
  *
  * Find the fully qualified style applicable to the specified cellpos.
  */
-MStyle *
+GnmStyle *
 sheet_style_get (Sheet const *sheet, int col, int row)
 {
 	int width = TILE_SIZE_COL*TILE_SIZE_COL*TILE_SIZE_COL;
@@ -1142,10 +1142,10 @@ tail_recursion :
 #define border_null(b)	((b) == none || (b) == NULL)
 
 static inline void
-style_row (MStyle *style, int start_col, int end_col, StyleRow *sr)
+style_row (GnmStyle *style, int start_col, int end_col, GnmRow *sr)
 {
-	StyleBorder const *top, *bottom, *none = style_border_none ();
-	StyleBorder const *left, *right, *v;
+	GnmBorder const *top, *bottom, *none = style_border_none ();
+	GnmBorder const *left, *right, *v;
 	int const end = MIN (end_col, sr->end_col);
 	int i = MAX (start_col, sr->start_col);
 
@@ -1184,7 +1184,7 @@ style_row (MStyle *style, int start_col, int end_col, StyleRow *sr)
 static void
 get_style_row (CellTile const *tile, int level,
 	       int corner_col, int corner_row,
-	       StyleRow *sr)
+	       GnmRow *sr)
 {
 	int const width = tile_widths [level+1];
 	int const w = tile_widths [level];
@@ -1220,7 +1220,7 @@ get_style_row (CellTile const *tile, int level,
 		corner_row += h*r;
 
 		if (t != TILE_PTR_MATRIX) {
-			MStyle * const *styles = tile->style_any.style + r*TILE_SIZE_COL;
+			GnmStyle * const *styles = tile->style_any.style + r*TILE_SIZE_COL;
 
 			for ( ; c <= last_c ; c++, corner_col += w)
 				style_row (styles [c],
@@ -1247,7 +1247,7 @@ get_style_row (CellTile const *tile, int level,
  * It also merges adjacent borders as necessary.
  */
 void
-sheet_style_get_row (Sheet const *sheet, StyleRow *sr)
+sheet_style_get_row (Sheet const *sheet, GnmRow *sr)
 {
 
 	g_return_if_fail (IS_SHEET (sheet));
@@ -1264,16 +1264,16 @@ sheet_style_get_row (Sheet const *sheet, StyleRow *sr)
 /**
  * style_row_init :
  *
- * A small utility routine to initialize the grid drawing StyleRow data
+ * A small utility routine to initialize the grid drawing GnmRow data
  * structure.
  */
 void
-style_row_init (StyleBorder const * * *prev_vert,
-		StyleRow *sr, StyleRow *next_sr,
+style_row_init (GnmBorder const * * *prev_vert,
+		GnmRow *sr, GnmRow *next_sr,
 		int start_col, int end_col, gpointer mem, gboolean hide_grid)
 {
 	int n, col;
-	StyleBorder const *none = hide_grid ? NULL : style_border_none ();
+	GnmBorder const *none = hide_grid ? NULL : style_border_none ();
 
 	/* alias the arrays for easy access so that array [col] is valid
 	 * for all elements start_col-1 .. end_col+1 inclusive.
@@ -1288,7 +1288,7 @@ style_row_init (StyleBorder const * * *prev_vert,
 	next_sr->bottom	 = next_sr->top + n;
 	next_sr->vertical = next_sr->bottom + n;
 	*prev_vert	 = next_sr->vertical + n;
-	sr->styles	 = ((MStyle const **) (*prev_vert + n));
+	sr->styles	 = ((GnmStyle const **) (*prev_vert + n));
 	next_sr->styles	 = sr->styles + n;
 	sr->start_col	 = next_sr->start_col = start_col;
 	sr->end_col	 = next_sr->end_col   = end_col;
@@ -1313,7 +1313,7 @@ style_row_init (StyleBorder const * * *prev_vert,
  * The routine absorbs a reference to the partial style.
  */
 void
-sheet_style_apply_range (Sheet *sheet, Range const *range, MStyle *pstyle)
+sheet_style_apply_range (Sheet *sheet, GnmRange const *range, GnmStyle *pstyle)
 {
 	ReplacementStyle rs;
 
@@ -1327,11 +1327,11 @@ sheet_style_apply_range (Sheet *sheet, Range const *range, MStyle *pstyle)
 }
 
 static void
-apply_border (Sheet *sheet, Range const *r,
+apply_border (Sheet *sheet, GnmRange const *r,
 	      StyleBorderLocation side,
-	      StyleBorder *border)
+	      GnmBorder *border)
 {
-	MStyle *pstyle = mstyle_new ();
+	GnmStyle *pstyle = mstyle_new ();
 	pstyle_set_border (pstyle, border, side);
 	sheet_style_apply_range (sheet, r, pstyle);
 }
@@ -1351,17 +1351,17 @@ apply_border (Sheet *sheet, Range const *r,
  */
 void
 sheet_style_apply_border (Sheet       *sheet,
-			  Range const *range,
-			  StyleBorder **borders)
+			  GnmRange const *range,
+			  GnmBorder **borders)
 {
-	MStyle *pstyle = NULL;
+	GnmStyle *pstyle = NULL;
 
 	if (borders == NULL)
 		return;
 
 	if (borders [STYLE_BORDER_TOP]) {
 		/* 1.1 top inner */
-		Range r = *range;
+		GnmRange r = *range;
 		r.end.row = r.start.row;
 		apply_border (sheet, &r, STYLE_BORDER_TOP,
 			      borders [STYLE_BORDER_TOP]);
@@ -1377,7 +1377,7 @@ sheet_style_apply_border (Sheet       *sheet,
 
 	if (borders [STYLE_BORDER_BOTTOM]) {
 		/* 2.1 bottom inner */
-		Range r = *range;
+		GnmRange r = *range;
 		r.start.row = r.end.row;
 		apply_border (sheet, &r, STYLE_BORDER_BOTTOM,
 			      borders [STYLE_BORDER_BOTTOM]);
@@ -1393,7 +1393,7 @@ sheet_style_apply_border (Sheet       *sheet,
 
 	if (borders [STYLE_BORDER_LEFT]) {
 		/* 3.1 left inner */
-		Range r = *range;
+		GnmRange r = *range;
 		r.end.col = r.start.col;
 		apply_border (sheet, &r, STYLE_BORDER_LEFT,
 			      borders [STYLE_BORDER_LEFT]);
@@ -1409,7 +1409,7 @@ sheet_style_apply_border (Sheet       *sheet,
 
 	if (borders [STYLE_BORDER_RIGHT]) {
 		/* 4.1 right inner */
-		Range r = *range;
+		GnmRange r = *range;
 		r.start.col = r.end.col;
 		apply_border (sheet, &r, STYLE_BORDER_RIGHT,
 			      borders [STYLE_BORDER_RIGHT]);
@@ -1427,14 +1427,14 @@ sheet_style_apply_border (Sheet       *sheet,
 	if (borders [STYLE_BORDER_HORIZ] != NULL) {
 		/* 5.1 horizontal interior top */
 		if (range->start.row != range->end.row) {
-			Range r = *range;
+			GnmRange r = *range;
 			++r.start.row;
 			apply_border (sheet, &r, STYLE_BORDER_TOP,
 				      borders [STYLE_BORDER_HORIZ]);
 		}
 		/* 5.2 interior bottom */
 		if (range->start.row != range->end.row) {
-			Range r = *range;
+			GnmRange r = *range;
 			--r.end.row;
 			apply_border (sheet, &r, STYLE_BORDER_BOTTOM,
 				      style_border_none ());
@@ -1445,7 +1445,7 @@ sheet_style_apply_border (Sheet       *sheet,
 	if (borders [STYLE_BORDER_VERT] != NULL) {
 		/* 6.1 vertical interior left */
 		if (range->start.col != range->end.col) {
-			Range r = *range;
+			GnmRange r = *range;
 			++r.start.col;
 			apply_border (sheet, &r, STYLE_BORDER_LEFT,
 				      borders [STYLE_BORDER_VERT]);
@@ -1453,7 +1453,7 @@ sheet_style_apply_border (Sheet       *sheet,
 
 		/* 6.2 The vertical interior right */
 		if (range->start.col != range->end.col) {
-			Range r = *range;
+			GnmRange r = *range;
 			--r.end.col;
 			apply_border (sheet, &r, STYLE_BORDER_RIGHT,
 				      style_border_none ());
@@ -1479,21 +1479,21 @@ sheet_style_apply_border (Sheet       *sheet,
 /****************************************************************************/
 
 static void
-cb_filter_style (MStyle *style,
+cb_filter_style (GnmStyle *style,
 		 int corner_col, int corner_row, int width, int height,
-		 Range const *apply_to, gpointer user)
+		 GnmRange const *apply_to, gpointer user)
 {
-	MStyle *accumulator = user;
+	GnmStyle *accumulator = user;
 	mstyle_compare (accumulator, style);
 }
 
 static void
-border_mask_internal (gboolean *known, StyleBorder **borders,
-		      StyleBorder const *b, StyleBorderLocation l)
+border_mask_internal (gboolean *known, GnmBorder **borders,
+		      GnmBorder const *b, StyleBorderLocation l)
 {
 	if (!known [l]) {
 		known [l] = TRUE;
-		borders [l] = (StyleBorder *)b;
+		borders [l] = (GnmBorder *)b;
 		style_border_ref (borders [l]);
 	} else if (borders [l] != b && borders [l] != NULL) {
 		style_border_unref (borders [l]);
@@ -1502,8 +1502,8 @@ border_mask_internal (gboolean *known, StyleBorder **borders,
 }
 
 static void
-border_mask (gboolean *known, StyleBorder **borders,
-	     StyleBorder const *b, StyleBorderLocation l)
+border_mask (gboolean *known, GnmBorder **borders,
+	     GnmBorder const *b, StyleBorderLocation l)
 {
 	if (b == NULL)
 		b = style_border_none ();
@@ -1511,16 +1511,16 @@ border_mask (gboolean *known, StyleBorder **borders,
 }
 
 static void
-border_mask_vec (gboolean *known, StyleBorder **borders,
-		 StyleBorder const * const *vec, int first, int last,
+border_mask_vec (gboolean *known, GnmBorder **borders,
+		 GnmBorder const * const *vec, int first, int last,
 		 StyleBorderLocation l)
 {
-	StyleBorder const *b = vec [first];
+	GnmBorder const *b = vec [first];
 
 	if (b == NULL)
 		b = style_border_none ();
 	while (first++ < last) {
-		StyleBorder const *tmp = vec [first];
+		GnmBorder const *tmp = vec [first];
 		if (tmp == NULL)
 			tmp = style_border_none ();
 		if (b != tmp) {
@@ -1542,14 +1542,14 @@ border_mask_vec (gboolean *known, StyleBorder **borders,
  * Find out what style elements are common to every cell in a range.
  */
 void
-sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
-			 MStyle **style, StyleBorder **borders)
+sheet_style_get_uniform	(Sheet const *sheet, GnmRange const *r,
+			 GnmStyle **style, GnmBorder **borders)
 {
 	int n, col, row, start_col, end_col;
-	StyleRow sr;
+	GnmRow sr;
 	StyleBorderLocation i;
 	gboolean known [STYLE_BORDER_EDGE_MAX];
-	StyleBorder const *none = style_border_none ();
+	GnmBorder const *none = style_border_none ();
 
 	g_return_if_fail (IS_SHEET (sheet));
 	g_return_if_fail (r != NULL);
@@ -1558,13 +1558,13 @@ sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 
 	/* init style set with a copy of the top left corner of the 1st range */
 	if (*style == NULL) {
-		MStyle const *tmp;
+		GnmStyle const *tmp;
 
 		tmp = sheet_style_get (sheet, r->start.col, r->start.row);
 		*style = mstyle_copy (tmp);
 		for (i = STYLE_BORDER_TOP ; i < STYLE_BORDER_EDGE_MAX ; i++) {
 			known [i] = FALSE;
-			borders [i] = style_border_ref ((StyleBorder *)none);
+			borders [i] = style_border_ref ((GnmBorder *)none);
 		}
 	} else {
 		for (i = STYLE_BORDER_TOP ; i < STYLE_BORDER_EDGE_MAX ; i++)
@@ -1592,12 +1592,12 @@ sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 
 	/* allocate then alias the arrays for easy access */
 	n = end_col - start_col + 2;
-	sr.vertical	 = (StyleBorder const **)g_alloca (n *
-			    (3 * sizeof (StyleBorder const *) +
-			     sizeof (MStyle const *)));
+	sr.vertical	 = (GnmBorder const **)g_alloca (n *
+			    (3 * sizeof (GnmBorder const *) +
+			     sizeof (GnmStyle const *)));
 	sr.top	      = sr.vertical + n;
 	sr.bottom     = sr.top + n;
-	sr.styles     = ((MStyle const **) (sr.bottom + n));
+	sr.styles     = ((GnmStyle const **) (sr.bottom + n));
 	sr.vertical  -= start_col; sr.top     -= start_col;
 	sr.bottom    -= start_col; sr.styles  -= start_col;
 	sr.start_col  = start_col; sr.end_col  = end_col;
@@ -1609,7 +1609,7 @@ sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 
 	/* merge the bottom of the previous row */
  	if (r->start.row > 0) {
-		StyleBorder const ** roller;
+		GnmBorder const ** roller;
 		sr.row = r->start.row - 1;
 		sheet_style_get_row (sheet, &sr);
 		roller = sr.top; sr.top = sr.bottom; sr.bottom = roller;
@@ -1624,7 +1624,7 @@ sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 	 * faster)
 	 */
 	for (row = r->start.row ; row <= r->end.row ; row++) {
-		StyleBorder const **roller;
+		GnmBorder const **roller;
 		sr.row = row;
 		sheet_style_get_row (sheet, &sr);
 
@@ -1662,8 +1662,8 @@ sheet_style_get_uniform	(Sheet const *sheet, Range const *r,
 void
 sheet_style_relocate (GnmExprRelocateInfo const *rinfo)
 {
-	CellPos corner;
-	StyleList *styles;
+	GnmCellPos corner;
+	GnmStyleList *styles;
 
 	g_return_if_fail (rinfo != NULL);
 
@@ -1689,9 +1689,9 @@ sheet_style_relocate (GnmExprRelocateInfo const *rinfo)
 void
 sheet_style_insert_colrow (GnmExprRelocateInfo const *rinfo)
 {
-	CellPos corner;
-	StyleList *ptr, *styles = NULL;
-	Range r;
+	GnmCellPos corner;
+	GnmStyleList *ptr, *styles = NULL;
+	GnmRange r;
 
 	g_return_if_fail (rinfo != NULL);
 	g_return_if_fail (rinfo->origin_sheet == rinfo->target_sheet);
@@ -1709,7 +1709,7 @@ sheet_style_insert_colrow (GnmExprRelocateInfo const *rinfo)
 			       range_init (&r, col, 0, col, SHEET_MAX_ROWS-1));
 		if (o > 0)
 			for (ptr = styles ; ptr != NULL ; ptr = ptr->next)
-				((StyleRegion *)ptr->data)->range.end.col = o;
+				((GnmStyleRegion *)ptr->data)->range.end.col = o;
 
 	} else if (rinfo->row_offset != 0) {
 		int const o = rinfo->row_offset - 1;
@@ -1721,7 +1721,7 @@ sheet_style_insert_colrow (GnmExprRelocateInfo const *rinfo)
 			       range_init (&r, 0, row, SHEET_MAX_COLS-1, row));
 		if (o > 0)
 			for (ptr = styles ; ptr != NULL ; ptr = ptr->next)
-				((StyleRegion *)ptr->data)->range.end.row = o;
+				((GnmStyleRegion *)ptr->data)->range.end.row = o;
 	}
 
 	sheet_style_relocate (rinfo);
@@ -1733,9 +1733,9 @@ sheet_style_insert_colrow (GnmExprRelocateInfo const *rinfo)
 }
 
 static void
-cb_visible_content (MStyle *style,
+cb_visible_content (GnmStyle *style,
 		    int corner_col, int corner_row, int width, int height,
-		    Range const *apply_to, gpointer res)
+		    GnmRange const *apply_to, gpointer res)
 {
 	*((gboolean *)res) |= mstyle_visible_in_blank (style);
 }
@@ -1751,7 +1751,7 @@ cb_visible_content (MStyle *style,
  * edges IF they have been seen before.
  */
 gboolean
-sheet_style_has_visible_content (Sheet const *sheet, Range *src)
+sheet_style_has_visible_content (Sheet const *sheet, GnmRange *src)
 {
 	gboolean res = FALSE;
 	foreach_tile (sheet->style_data->styles,
@@ -1761,14 +1761,14 @@ sheet_style_has_visible_content (Sheet const *sheet, Range *src)
 }
 
 typedef struct {
-	Range *res;
-	MStyle **most_common_in_cols;
+	GnmRange *res;
+	GnmStyle **most_common_in_cols;
 } StyleExtentData;
 
 static void
-cb_style_extent (MStyle *style,
+cb_style_extent (GnmStyle *style,
 		 int corner_col, int corner_row, int width, int height,
-		 Range const *apply_to, gpointer user)
+		 GnmRange const *apply_to, gpointer user)
 {
 	StyleExtentData *data = user;
 	if (mstyle_visible_in_blank (style)) {
@@ -1807,11 +1807,11 @@ cb_style_extent (MStyle *style,
  * boundary calculations.
  */
 void
-sheet_style_get_extent (Sheet const *sheet, Range *res,
-			MStyle **most_common_in_cols)
+sheet_style_get_extent (Sheet const *sheet, GnmRange *res,
+			GnmStyle **most_common_in_cols)
 {
 	StyleExtentData data;
-	Range r;
+	GnmRange r;
 
 	if (most_common_in_cols != NULL) {
 		unsigned i;
@@ -1829,12 +1829,12 @@ sheet_style_get_extent (Sheet const *sheet, Range *res,
 
 /****************************************************************************/
 
-static StyleRegion *
-style_region_new (Range const *range, MStyle *mstyle)
+static GnmStyleRegion *
+style_region_new (GnmRange const *range, GnmStyle *mstyle)
 {
-	StyleRegion *sr;
+	GnmStyleRegion *sr;
 
-	sr = g_new (StyleRegion, 1);
+	sr = g_new (GnmStyleRegion, 1);
 	sr->range = *range;
 	sr->style = mstyle;
 	mstyle_ref (mstyle);
@@ -1843,7 +1843,7 @@ style_region_new (Range const *range, MStyle *mstyle)
 }
 
 static void
-style_region_free (StyleRegion *sr)
+style_region_free (GnmStyleRegion *sr)
 {
 	g_return_if_fail (sr != NULL);
 
@@ -1854,18 +1854,18 @@ style_region_free (StyleRegion *sr)
 
 typedef struct {
 	GHashTable *cache;
-	gboolean (*style_equal) (MStyle const *a, MStyle const *b);
+	gboolean (*style_equal) (GnmStyle const *a, GnmStyle const *b);
 } StyleListMerge;
 
 static void
-cb_style_list_add_node (MStyle *style,
+cb_style_list_add_node (GnmStyle *style,
 			int corner_col, int corner_row, int width, int height,
-			Range const *apply_to, gpointer user)
+			GnmRange const *apply_to, gpointer user)
 {
 	StyleListMerge *mi = user;
-	StyleRegion *sr = NULL;
-	CellPos	key;
-	Range range;
+	GnmStyleRegion *sr = NULL;
+	GnmCellPos	key;
+	GnmRange range;
 
 	range.start.col = corner_col;
 	range.start.row = corner_row;
@@ -1895,7 +1895,7 @@ cb_style_list_add_node (MStyle *style,
 	key.col = range.end.col;
 	key.row = range.start.row - 1;
 	if (key.row >= 0 &&
-	    (sr = (StyleRegion *)g_hash_table_lookup (mi->cache, &key)) != NULL &&
+	    (sr = (GnmStyleRegion *)g_hash_table_lookup (mi->cache, &key)) != NULL &&
 	    sr->range.start.col == range.start.col && (mi->style_equal) (sr->style, style)) {
 		g_hash_table_remove (mi->cache, &key);
 		sr->range.end.row = range.end.row;
@@ -1909,8 +1909,8 @@ static gboolean
 cb_hash_merge_horiz (gpointer hash_key, gpointer value, gpointer user)
 {
 	StyleListMerge *mi = user;
-	StyleRegion *sr = value, *srh;
-	CellPos	key;
+	GnmStyleRegion *sr = value, *srh;
+	GnmCellPos	key;
 
 #ifdef DEBUG_STYLE_LIST
 	range_dump (&sr->range, "\n");
@@ -1927,7 +1927,7 @@ cb_hash_merge_horiz (gpointer hash_key, gpointer value, gpointer user)
 	do {
 		key.col = sr->range.start.col - 1;
 		if (key.col >= 0 &&
-		    (srh = (StyleRegion *)g_hash_table_lookup (mi->cache, &key)) != NULL &&
+		    (srh = (GnmStyleRegion *)g_hash_table_lookup (mi->cache, &key)) != NULL &&
 		    srh->range.start.row == sr->range.start.row && (mi->style_equal) (sr->style, srh->style)) {
 			g_return_val_if_fail (srh->range.start.col >= 0, FALSE);
 			sr->range.start.col = srh->range.start.col;
@@ -1941,8 +1941,8 @@ cb_hash_merge_horiz (gpointer hash_key, gpointer value, gpointer user)
 static gboolean
 cb_hash_to_list (gpointer key, gpointer	value, gpointer	user_data)
 {
-	StyleList **res = user_data;
-	StyleRegion *sr = value;
+	GnmStyleList **res = user_data;
+	GnmStyleRegion *sr = value;
 
 	/* Already merged */
 	if (sr->range.start.col < 0) {
@@ -1967,15 +1967,15 @@ cb_hash_to_list (gpointer key, gpointer	value, gpointer	user_data)
  * Get a list of rectangles and their associated styles
  * Caller is responsible for freeing.
  */
-StyleList *
-sheet_style_get_list (Sheet const *sheet, Range const *r)
+GnmStyleList *
+sheet_style_get_list (Sheet const *sheet, GnmRange const *r)
 {
-	StyleList *res = NULL;
+	GnmStyleList *res = NULL;
 	StyleListMerge mi;
 
 	mi.style_equal = mstyle_equal;
 	mi.cache = g_hash_table_new ((GHashFunc)&cellpos_hash,
-				     (GCompareFunc)&cellpos_cmp);
+				     (GCompareFunc)&cellpos_equal);
 
 	foreach_tile (sheet->style_data->styles,
 		      TILE_TOP_LEVEL, 0, 0, r,
@@ -1994,10 +1994,10 @@ sheet_style_get_list (Sheet const *sheet, Range const *r)
 }
 
 static void
-cb_style_list_add_validation (MStyle *style,
+cb_style_list_add_validation (GnmStyle *style,
 			      int corner_col, int corner_row,
 			      int width, int height,
-			      Range const *apply_to, gpointer user)
+			      GnmRange const *apply_to, gpointer user)
 {
 	/* collect only the area with validation */
 	if (NULL != mstyle_get_validation (style) ||
@@ -2007,7 +2007,7 @@ cb_style_list_add_validation (MStyle *style,
 }
 
 static gboolean
-style_validation_equal (MStyle const *a, MStyle const *b)
+style_validation_equal (GnmStyle const *a, GnmStyle const *b)
 {
 	return	mstyle_get_validation (a) == mstyle_get_validation (b) &&
 		mstyle_get_input_msg (a) == mstyle_get_input_msg (b);
@@ -2022,15 +2022,15 @@ style_validation_equal (MStyle const *a, MStyle const *b)
  * Get a list of areas with validation
  * Caller is responsible for freeing.
  */
-StyleList *
-sheet_style_get_validation_list (Sheet const *sheet, Range const *r)
+GnmStyleList *
+sheet_style_get_validation_list (Sheet const *sheet, GnmRange const *r)
 {
-	StyleList *res = NULL;
+	GnmStyleList *res = NULL;
 	StyleListMerge mi;
 
 	mi.style_equal = style_validation_equal;
 	mi.cache = g_hash_table_new ((GHashFunc)&cellpos_hash,
-				     (GCompareFunc)&cellpos_cmp);
+				     (GCompareFunc)&cellpos_equal);
 
 	foreach_tile (sheet->style_data->styles,
 		      TILE_TOP_LEVEL, 0, 0, r,
@@ -2060,18 +2060,18 @@ sheet_style_get_validation_list (Sheet const *sheet, Range const *r)
  * transposing the ranges
  */
 SpanCalcFlags
-sheet_style_set_list (Sheet *sheet, CellPos const *corner,
-		      gboolean transpose, StyleList const *list)
+sheet_style_set_list (Sheet *sheet, GnmCellPos const *corner,
+		      gboolean transpose, GnmStyleList const *list)
 {
 	SpanCalcFlags spanflags = SPANCALC_SIMPLE;
-	StyleList const *l;
+	GnmStyleList const *l;
 
 	g_return_val_if_fail (IS_SHEET (sheet), spanflags);
 
 	/* Sluggish but simple implementation for now */
 	for (l = list; l; l = l->next) {
-		StyleRegion const *sr = l->data;
-		Range              r  = sr->range;
+		GnmStyleRegion const *sr = l->data;
+		GnmRange              r  = sr->range;
 
 		range_translate (&r, +corner->col, +corner->row);
 		if (transpose)
@@ -2093,9 +2093,9 @@ sheet_style_set_list (Sheet *sheet, CellPos const *corner,
  * styles.
  */
 void
-style_list_free (StyleList *list)
+style_list_free (GnmStyleList *list)
 {
-	StyleList *l;
+	GnmStyleList *l;
 
 	for (l = list; l; l = l->next)
 		style_region_free (l->data);
@@ -2112,16 +2112,16 @@ style_list_free (StyleList *list)
  * based style list.
  * The resulting style does not have its reference count bumped.
  */
-MStyle const *
-style_list_get_style (StyleList const *list, CellPos const *pos)
+GnmStyle const *
+style_list_get_style (GnmStyleList const *list, GnmCellPos const *pos)
 {
-	StyleList const *l;
+	GnmStyleList const *l;
 
 	g_return_val_if_fail (pos != NULL, NULL);
 
 	for (l = list; l; l = l->next) {
-		StyleRegion const *sr = l->data;
-		Range const *r = &sr->range;
+		GnmStyleRegion const *sr = l->data;
+		GnmRange const *r = &sr->range;
 		if (range_contains (r, pos->col, pos->row))
 			return sr->style;
 	}
@@ -2129,9 +2129,9 @@ style_list_get_style (StyleList const *list, CellPos const *pos)
 }
 
 static void
-cb_accumulate_count (MStyle *style,
+cb_accumulate_count (GnmStyle *style,
 		     int corner_col, int corner_row, int width, int height,
-		     Range const *apply_to, gpointer accumulator)
+		     GnmRange const *apply_to, gpointer accumulator)
 {
 	gpointer count;
 
@@ -2146,7 +2146,7 @@ cb_accumulate_count (MStyle *style,
 
 typedef struct
 {
-	MStyle *style;
+	GnmStyle *style;
 	int     count;
 } MostCommon;
 
@@ -2171,12 +2171,12 @@ cb_find_max (gpointer key, gpointer value, gpointer user_data)
  * Find the most common style in a column.
  * The resulting style does not have its reference count bumped.
  */
-MStyle *
+GnmStyle *
 sheet_style_most_common_in_col (Sheet const *sheet, int col)
 {
 	MostCommon  res;
 	GHashTable *accumulator;
-	Range       r;
+	GnmRange       r;
 
 	r.start.col = r.end.col = col;
 	r.start.row = 0; r.end.row = SHEET_MAX_ROWS-1;
@@ -2192,9 +2192,9 @@ sheet_style_most_common_in_col (Sheet const *sheet, int col)
 }
 
 static void
-cb_find_link (MStyle *style,
+cb_find_link (GnmStyle *style,
 	      int corner_col, int corner_row, int width, int height,
-	      Range const *apply_to, gpointer user)
+	      GnmRange const *apply_to, gpointer user)
 {
 	GnmHLink **link = user;
 	if (*link == NULL)
@@ -2210,7 +2210,7 @@ cb_find_link (MStyle *style,
  * and returns the 1st one it finds.
  **/
 GnmHLink *
-sheet_style_region_contains_link (Sheet const *sheet, Range const *r)
+sheet_style_region_contains_link (Sheet const *sheet, GnmRange const *r)
 {
 	GnmHLink *res = NULL;
 
@@ -2225,12 +2225,12 @@ sheet_style_region_contains_link (Sheet const *sheet, Range const *r)
 
 #if 0
 static void
-cb_validate (MStyle *style,
+cb_validate (GnmStyle *style,
 	     int corner_col, int corner_row, int width, int height,
-	     Range const *apply_to, Sheet const *sheet)
+	     GnmRange const *apply_to, Sheet const *sheet)
 {
 	if (g_hash_table_lookup (sheet->style_data->style_hash, style) == NULL) {
-		Range r;
+		GnmRange r;
 		range_init (&r,
 			   corner_col, corner_row,
 			   corner_col+width -1, corner_row+height-1);
