@@ -56,7 +56,7 @@ typedef struct {
 	int                  colcount;              /* Number of columns parsed */
         gboolean             *col_import_array;     /* 0/1 array indicating  */
 	                                            /* which cols to import  */
-	GPtrArray            *formats       ;       /* Contains StyleFormat *s */
+	GPtrArray            *formats       ;       /* Contains GnmFormat *s */
 } StfParseOptions_t;
 
 /* CREATION/DESTRUCTION of stf options struct */
@@ -96,11 +96,15 @@ int stf_parse_options_fixed_splitpositions_nth         (StfParseOptions_t *parse
 /* USING the stf structs to actually do some parsing, these are the lower-level functions and utility functions */
 
 GPtrArray          *stf_parse_general                                 (StfParseOptions_t *parseoptions,
+								       GStringChunk *lines_chunk,
 								       char const *data,
-								       char const *data_end);
+								       char const *data_end,
+								       int maxlines);
 void                stf_parse_general_free                            (GPtrArray *lines);
 GPtrArray          *stf_parse_lines                                   (StfParseOptions_t *parseoptions,
+								       GStringChunk *lines_chunk,
 								       const char *data,
+								       int maxlines,
 								       gboolean with_lineno);
 
 void                stf_parse_options_fixed_autodiscover              (StfParseOptions_t *parseoptions,
@@ -121,6 +125,6 @@ gboolean	    stf_parse_sheet                                   (StfParseOptions_
 								       Sheet *sheet,
 								       int start_col, int start_row);
 
-CellRegion         *stf_parse_region                                  (StfParseOptions_t *parseoptions,
+GnmCellRegion         *stf_parse_region                                  (StfParseOptions_t *parseoptions,
 								       char const *data, char const *data_end);
 #endif
